@@ -113,7 +113,7 @@ long ArchInputDialog::onCmdBrowsePath(FXObject* o,FXSelector s,void* p)
 	// File dialog
 	FileDialog browse(this,_("Select a destination folder"));	
 
-	const FXchar *patterns[]=
+	const char *patterns[]=
 		{
 			_("All Files"),          "*",	NULL
 		};
@@ -167,7 +167,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.gz";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".tar.gz";
@@ -203,7 +203,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 	{
 
 		// Handle different archive formats
-		if (ext2=="tar.bz2" || ext1=="tbz2")
+		if (ext2=="tar.bz2" || ext1=="tbz2" || ext1=="tbz")
 		{
 			input->setText(str);
 		}
@@ -320,7 +320,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".tar";
@@ -370,7 +370,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.Z";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".tar.Z";
@@ -426,7 +426,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".gz";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".gz";
@@ -482,7 +482,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".xz";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".xz";
@@ -539,7 +539,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".bz2";
@@ -595,7 +595,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".Z";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".Z";
@@ -645,7 +645,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".zip";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".zip";
@@ -701,7 +701,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".7z";
 			input->setText(str);
 		}
-		else if (ext1=="tbz2")
+		else if (ext1=="tbz2" || ext1=="tbz")
 		{
 			str=str.left(str.length()-5);
 			str=str+".7z";
@@ -751,7 +751,7 @@ long ArchInputDialog::onUpdOption(FXObject*,FXSelector sel,void*)
 	{
 		optionmenu->setCurrent(option_tgz);	
 	}
-	else if (ext2=="tar.bz2" || ext1=="tbz2")
+	else if (ext2=="tar.bz2" || ext1=="tbz2" || ext1=="tbz")
 	{
 		optionmenu->setCurrent(option_tbz2);	
 	}
