@@ -45,18 +45,18 @@ Bookmarks::Bookmarks(const FXString& gp,FXObject *tgt,FXSelector sel):group(gp),
 
 
 // Obtain the bookmark at index
-FXString Bookmarks::getBookmark(FXint index) const
+FXString Bookmarks::getBookmark(int index) const
 {
-    FXchar key[20];
+    char key[20];
     snprintf(key,sizeof(key)-1,"BOOKMARK%d",index);
     return FXApp::instance()->reg().readStringEntry(group.text(),key,FXString::null);
 }
 
 
 // Change the bookmark at index
-void Bookmarks::setBookmark(FXint index,const FXString& bookname)
+void Bookmarks::setBookmark(int index,const FXString& bookname)
 {
-    FXchar key[20];
+    char key[20];
     snprintf(key,sizeof(key)-1,"BOOKMARK%d",index);
     FXApp::instance()->reg().writeStringEntry(group.text(),key,bookname.text());
 }
@@ -68,8 +68,8 @@ void Bookmarks::appendBookmark(const FXString& bookname)
 {
     FXString newname=bookname;
     FXString oldname;
-    FXchar key[20];
-    FXint i=1,j=1;
+    char key[20];
+    int i=1,j=1;
 	
 	FXApp::instance()->reg().read();
     do
@@ -96,9 +96,9 @@ void Bookmarks::appendBookmark(const FXString& bookname)
 // Remove a bookmark
 void Bookmarks::removeBookmark(const FXString& bookname)
 {
-    FXchar key[20];
+    char key[20];
     FXString name;
-    FXint i=1,j=1;
+    int i=1,j=1;
     do
     {
         snprintf(key,sizeof(key)-1,"BOOKMARK%d",i++);
@@ -141,8 +141,8 @@ long Bookmarks::onCmdClear(FXObject*,FXSelector,void*)
 // User clicks on one of the bookmark names
 long Bookmarks::onCmdBookmark(FXObject*,FXSelector sel,void*)
 {
-    const FXchar *bookname;
-    FXchar key[20];
+    const char *bookname;
+    char key[20];
     if(target)
     {
         snprintf(key,sizeof(key)-1,"BOOKMARK%d",(FXSELID(sel)-ID_BOOKMARK_1+1));
@@ -157,11 +157,11 @@ long Bookmarks::onCmdBookmark(FXObject*,FXSelector sel,void*)
 // Update handler for same
 long Bookmarks::onUpdBookmark(FXObject *sender,FXSelector sel,void*)
 {
-    FXint which=FXSELID(sel)-ID_BOOKMARK_1+1;
-    const FXchar *bookname=NULL;
+    int which=FXSELID(sel)-ID_BOOKMARK_1+1;
+    const char *bookname=NULL;
     FXString string;
-    FXchar key[20];
-    FXchar _char[11]={'a','b','c','d','e','f','g','h','i','j','k'};
+    char key[20];
+    char _char[11]={'a','b','c','d','e','f','g','h','i','j','k'};
     snprintf(key,sizeof(key)-1,"BOOKMARK%d",which);
     bookname=FXApp::instance()->reg().readStringEntry(group.text(),key,NULL);
     if(bookname)
