@@ -8,7 +8,7 @@ protected:
     FXString    group;          // MRU File group
     FXObject   *target;         // Target object to send message
     FXSelector  message;        // Message to send
-    FXint       maxbookmarks;       // Maximum number of bookmarks to track
+    int       maxbookmarks;       // Maximum number of bookmarks to track
 private:
     Bookmarks(const Bookmarks&);
     Bookmarks &operator=(const Bookmarks&);
@@ -52,13 +52,13 @@ public:
     Bookmarks(const FXString& gp,FXObject *tgt=NULL,FXSelector sel=0);
 
     // Change number of bookmarks we're tracking
-    void setMaxBookmarks(FXint mx)
+    void setMaxBookmarks(int mx)
     {
         maxbookmarks=mx;
     }
 
     // Return the maximum number of bookmarks being tracked
-    FXint getMaxBookmarks() const
+    int getMaxBookmarks() const
     {
         return maxbookmarks;
     }
@@ -100,10 +100,10 @@ public:
     }
 
     // Obtain the bookmark name at index
-    FXString getBookmark(FXint index) const;
+    FXString getBookmark(int index) const;
 
     // Change the bookmark name at index
-    void setBookmark(FXint index,const FXString& filename);
+    void setBookmark(int index,const FXString& filename);
 
     // Append a bookmark
     void appendBookmark(const FXString& filename);
