@@ -29,7 +29,7 @@ FXDEFMAP(BrowseInputDialog) BrowseInputDialogMap[]=
 FXIMPLEMENT(BrowseInputDialog,DialogBox,BrowseInputDialogMap,ARRAYNUMBER(BrowseInputDialogMap))
 
 // Construct a dialog box
-BrowseInputDialog::BrowseInputDialog(FXWindow *win,FXString inp,FXString message,FXString title,FXString label,FXIcon *ic, unsigned int browse, FXbool option, FXString optiontext):
+BrowseInputDialog::BrowseInputDialog(FXWindow *win,FXString inp,FXString message,FXString title,FXString label,FXIcon *ic, FXuint browse, FXbool option, FXString optiontext):
         DialogBox(win,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
     // Browse type flag
