@@ -23,7 +23,7 @@ protected:
     FXLabel*			iconlabel;
     FXDataTarget*      string_target;
     FXHorizontalFrame* checkbutton;
-	unsigned int			   browsetype;
+	FXuint			   browsetype;
 	FXString           initialdir;
 private:
     BrowseInputDialog()
@@ -36,7 +36,7 @@ public:
         ID_BROWSE_PATH=DialogBox::ID_LAST,
         ID_LAST
     };
-    BrowseInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, unsigned int browse=BROWSE_INPUT_FILE, FXbool option=FALSE, FXString=FXString::null);
+    BrowseInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, FXuint browse=BROWSE_INPUT_FILE, FXbool option=FALSE, FXString=FXString::null);
     virtual void create();
     virtual ~BrowseInputDialog();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
