@@ -9,8 +9,8 @@ class CommandWindow : public DialogBox
     FXDECLARE(CommandWindow)
 protected:
 
-    FXint         pid;                 // Proccess ID of child (valid if busy).
-    FXint         pipes[2];            // Pipes to communicate with child process.
+    int         pid;                 // Proccess ID of child (valid if busy).
+    int         pipes[2];            // Pipes to communicate with child process.
     FXChore      *wchore;		       // Chore to watch process.
     FXText       *text;
 
@@ -36,14 +36,14 @@ public:
 	long onUpdClose(FXObject* sender,FXSelector,void*);
     virtual void create();
     virtual ~CommandWindow();
-    FXint execCmd(FXString);
-    CommandWindow(FXWindow *owner, const FXString& name,  FXString strcmd, FXint nblines, FXint nbcols);
-    CommandWindow(FXApp *a, const FXString& name,  FXString strcmd, FXint nblines, FXint nbcols);
+    int execCmd(FXString);
+    CommandWindow(FXWindow *owner, const FXString& name,  FXString strcmd, int nblines, int nbcols);
+    CommandWindow(FXApp *a, const FXString& name,  FXString strcmd, int nblines, int nbcols);
 	long onCmdClose(FXObject*,FXSelector,void*);
-	void setText(const FXchar*);
-	void appendText(const FXchar* str);
+	void setText(const char*);
+	void appendText(const char* str);
 	void scrollToLastLine(void);
-	FXint getLength(void);
+	int getLength(void);
 };
 
 #endif
