@@ -31,7 +31,7 @@ FXIMPLEMENT(DirHistBox,DialogBox,DirHistBoxMap,ARRAYNUMBER(DirHistBoxMap))
 
 
 // Construct list box with given caption, icon, message text, and with choices from array of strings
-DirHistBox::DirHistBox(FXWindow* owner,const char** choices,unsigned int opts,int x,int y,int w,int h):
+DirHistBox::DirHistBox(FXWindow* owner,const char** choices,FXuint opts,int x,int y,int w,int h):
         DialogBox(owner,"",opts,x,y,w,h,0,0,0,0, 0,0)
 {
     register int n;
@@ -44,7 +44,7 @@ DirHistBox::DirHistBox(FXWindow* owner,const char** choices,unsigned int opts,in
 
 
 // Construct list box with given caption, icon, message text, and with choices from newline separated strings
-DirHistBox::DirHistBox(FXWindow* owner,const FXString& choices,unsigned int opts,int x,int y,int w,int h):
+DirHistBox::DirHistBox(FXWindow* owner,const FXString& choices,FXuint opts,int x,int y,int w,int h):
         DialogBox(owner,"",opts,x,y,w,h,0,0,0,0, 0,0)
 {
     register int n;
@@ -81,7 +81,7 @@ DirHistBox::~DirHistBox()
 
 
 // Show a modal list dialog
-int DirHistBox::box(FXWindow* owner,unsigned int opts,const char** choices,int x,int y,int w,int h)
+int DirHistBox::box(FXWindow* owner,FXuint opts,const char** choices,int x,int y,int w,int h)
 {
     DirHistBox box(owner,choices,opts,x,y,w,h);
     return box.execute(PLACEMENT_DEFAULT);
@@ -89,7 +89,7 @@ int DirHistBox::box(FXWindow* owner,unsigned int opts,const char** choices,int x
 
 
 // Show a modal list dialog
-int DirHistBox::box(FXWindow* owner,unsigned int opts,const FXString& choices,int x,int y,int w,int h)
+int DirHistBox::box(FXWindow* owner,FXuint opts,const FXString& choices,int x,int y,int w,int h)
 {
     DirHistBox box(owner,choices,opts,x,y,w,h);
     return box.execute(PLACEMENT_DEFAULT);
