@@ -103,7 +103,7 @@ FXIMPLEMENT(DirList,FXTreeList,DirListMap,ARRAYNUMBER(DirListMap))
 
 
 // Directory List Widget
-DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
+DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,int x,int y,int w,int h):
         FXTreeList(p,tgt,sel,opts,x,y,w,h),pattern("*")
 {
     flags|=FLAG_ENABLED|FLAG_DROPTARGET;
@@ -162,7 +162,7 @@ DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,
 			{
 				// To fix an issue with some Linux distributions
 				FXString mntdir=mnt->mnt_dir;
-				if (mntdir!="/dev/.static/dev" &&   mntdir.rfind(".gvfs",5,mntdir.length())==-1)
+				if (mntdir!="/dev/.static/dev" &&   mntdir.rfind("gvfs",4,mntdir.length())==-1)
 					mtdevices->insert(mnt->mnt_dir,mnt->mnt_type);
 			}
             endmntent(mtab);
@@ -181,7 +181,7 @@ DirList::DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt,FXSelector sel,
             {
 				// To fix an issue with some Linux distributions
 				FXString mntdir=mnt->mnt_dir;
-				if (mntdir!="/dev/.static/dev" &&   mntdir.rfind(".gvfs",5,mntdir.length())==-1)
+				if (mntdir!="/dev/.static/dev" &&   mntdir.rfind("gvfs",4,mntdir.length())==-1)
 				{
 					if (lstatmt(mnt->mnt_dir,&statbuf)==-1)
 						mtstate="down";
@@ -225,7 +225,7 @@ void DirList::create()
 long DirList::onExpandTimer(FXObject* sender,FXSelector sel,void* ptr)
 {
     int xx,yy;
-    unsigned int state;
+    FXuint state;
     DirItem *item;
 
     getCursorPosition(xx,yy,state);
@@ -362,7 +362,7 @@ long DirList::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr)
             {
                 acceptDrop(DRAG_ACCEPT);
                 int x,y;
-                unsigned int state;
+                FXuint state;
                 getCursorPosition(x,y,state);
                 TreeItem* item=(TreeItem*)getItemAt(x,y);
 
@@ -420,8 +420,8 @@ long DirList::onCmdDragReject(FXObject* sender,FXSelector sel,void* ptr)
 // Handle drag-and-drop drop
 long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 {
-	unsigned char *data;
-    unsigned int len;
+	FXuchar *data;
+    FXuint len;
     FXbool showdialog=TRUE;
 	int ret;
     File *f=NULL;
@@ -461,7 +461,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 		dropaction=DRAG_REJECT;
 		FXMenuPane menu(this);
 		int x,y;
-		unsigned int state;
+		FXuint state;
 		getRoot()->getCursorPosition(x,y,state);
 		new FXMenuCommand(&menu,_("Copy here"),copy_clpicon,this,DirList::ID_DRAG_COPY);
 		new FXMenuCommand(&menu,_("Move here"),moveiticon,this,DirList::ID_DRAG_MOVE);
@@ -487,7 +487,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
     //if(getDNDData(FROM_DRAGNDROP,urilistType,data,len))
     if(dnd)  // See comment upper
     {
-        FXRESIZE(&data,unsigned char,len+1);
+        FXRESIZE(&data,FXuchar,len+1);
         data[len]='\0';
         char *p,*q;
         p=q=(char*)data;
@@ -704,8 +704,8 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 long DirList::onDNDRequest(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXEvent *event=(FXEvent*)ptr;
-    unsigned char *data;
-    unsigned int len;
+    FXuchar *data;
+    FXuint len;
 
     // Perhaps the target wants to supply its own data
     if(FXTreeList::onDNDRequest(sender,sel,ptr))
@@ -717,7 +717,7 @@ long DirList::onDNDRequest(FXObject* sender,FXSelector sel,void* ptr)
         if(!dragfiles.empty())
         {
             len=dragfiles.length();
-            FXMEMDUP(&data,dragfiles.text(),unsigned char,len);
+            FXMEMDUP(&data,dragfiles.text(),FXuchar,len);
             setDNDData(FROM_DRAGNDROP,event->target,data,len);
         }
         return 1;
@@ -1095,7 +1095,7 @@ long DirList::onMtdevicesRefresh(FXObject*,FXSelector,void*)
 		{
 			// To fix an issue with some Linux distributions
 			FXString mntdir=mnt->mnt_dir;
-			if (mntdir!="/dev/.static/dev" &&   mntdir.rfind(".gvfs",5,mntdir.length())==-1)
+			if (mntdir!="/dev/.static/dev" &&   mntdir.rfind("gvfs",4,mntdir.length())==-1)
 			{
 				tmpdict->insert(mnt->mnt_dir,"");
 				if (mtdevices->find(mnt->mnt_dir))
@@ -1146,7 +1146,7 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
         {			
 			// To fix an issue with some Linux distributions
 			FXString mntdir=mnt->mnt_dir;
-			if (mntdir!="/dev/.static/dev" &&   mntdir.rfind(".gvfs",5,mntdir.length())==-1)
+			if (mntdir!="/dev/.static/dev" &&   mntdir.rfind("gvfs",4,mntdir.length())==-1)
 			{
 				tmpdict->insert(mnt->mnt_dir,"");
 
@@ -1348,7 +1348,7 @@ void DirList::listChildItems(DirItem *par)
 	FXString type, mod, usrid, grpid, atts, del;
 	FXString timeformat;
     int islink;
-	long deldate;
+	FXlong deldate;
 
     // Path to parent node
     directory=getItemPathname((TreeItem*)par);
@@ -1531,7 +1531,7 @@ fnd:
             // Update item information
             item->openIcon=openicon;
             item->closedIcon=closedicon;
-            item->size=(unsigned long)info.st_size;
+            item->size=(FXulong)info.st_size;
             item->assoc=fileassoc;
             item->date=info.st_mtime;
 
@@ -1855,7 +1855,7 @@ FXbool DirList::showFiles() const
 // Change list style
 void DirList::showFiles(FXbool showing)
 {
-    unsigned int opts=options;
+    FXuint opts=options;
     if(showing)
         opts|=DIRLIST_SHOWFILES;
     else
@@ -1878,7 +1878,7 @@ FXbool DirList::shownHiddenFiles() const
 // Change show hidden files mode
 void DirList::showHiddenFiles(FXbool showing)
 {
-    unsigned int opts=options;
+    FXuint opts=options;
     if(showing)
         opts|=DIRLIST_SHOWHIDDEN;
     else
@@ -1913,7 +1913,7 @@ void DirList::setPattern(const FXString& ptrn)
 
 
 // Change file match mode
-void DirList::setMatchMode(unsigned int mode)
+void DirList::setMatchMode(FXuint mode)
 {
     if(matchmode!=mode)
     {
