@@ -113,8 +113,8 @@ protected:
     FXDragAction	dropaction;				// Drop action
     FXString		dragfiles;				// Dragged files
     FXString		pattern;				// Pattern of file names
-    unsigned int			matchmode;				// File wildcard match mode
-    unsigned int			counter;				// Refresh counter
+    FXuint			matchmode;				// File wildcard match mode
+    FXuint			counter;				// Refresh counter
 	FXString		trashfileslocation;     // Location of the trash files directory
 	FXString		trashinfolocation;      // Location of the trash info directory
 	FXWindow		*focuswindow;			// Window used to test focus
@@ -203,7 +203,7 @@ public:
 public:
 
     // Construct a directory list
-    DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
+    DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
@@ -257,13 +257,13 @@ public:
     }
 
     // Return wildcard matching mode
-    unsigned int getMatchMode() const
+    FXuint getMatchMode() const
     {
         return matchmode;
     }
 
     // Change wildcard matching mode
-    void setMatchMode(unsigned int mode);
+    void setMatchMode(FXuint mode);
 
     // Return TRUE if showing files as well as directories
     FXbool showFiles() const;
