@@ -45,7 +45,7 @@ protected:
 
 public:
 DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0), FXbool smoothscroll=TRUE,
-         unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
+         FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
     DirPanel()
     {}
     virtual void create();
