@@ -47,7 +47,7 @@ FXDEFMAP(File) FileMap[]={
 FXIMPLEMENT(File,DialogBox,FileMap,ARRAYNUMBER(FileMap))
 
 // Construct object
-File::File(FXWindow *owner, FXString title, const unsigned int operation):DialogBox(owner,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
+File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(owner,title,DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
     // Progress window
 	FXPacker *buttons=new FXPacker(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,10,10,PROGRESSDIALOG_WIDTH,PROGRESSDIALOG_WIDTH,5,5);
@@ -64,7 +64,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
 	progressbar=NULL;
 	
 	// Progress bar colors (foreground, text and alternate text)
-	unsigned int r, g, b, l;
+	FXuint r, g, b, l;
 	FXColor textcolor, textaltcolor;
 	FXColor fgcolor=getApp()->reg().readColorEntry("SETTINGS","pbarcolor",FXRGB(0,0,255));
 	FXColor bgcolor=getApp()->reg().readColorEntry("SETTINGS","backcolor",FXRGB(0,0,255));
@@ -73,7 +73,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
 	r=FXREDVAL(fgcolor);                                                     
 	g=FXGREENVAL(fgcolor);                                                   
 	b=FXBLUEVAL(fgcolor);
-	l=(unsigned int)(0.3*r+0.59*g+0.11*b);                                                                                  
+	l=(FXuint)(0.3*r+0.59*g+0.11*b);                                                                                  
 	if (l<150)
 		textaltcolor=FXRGB(255,255,255);
 	else
@@ -83,7 +83,7 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):Dialog
 	r=FXREDVAL(bgcolor);                                                     
 	g=FXGREENVAL(bgcolor);                                                   
 	b=FXBLUEVAL(bgcolor);
-	l=(unsigned int)(0.3*r+0.59*g+0.11*b);                                                                                  
+	l=(FXuint)(0.3*r+0.59*g+0.11*b);                                                                                  
 	if (l<150)
 		textcolor=FXRGB(255,255,255);
 	else
@@ -220,7 +220,7 @@ void File::restartTimeout(void)
 
 
 // Read bytes
-FXlong File::fullread(int fd, unsigned char* ptr, FXlong len)
+FXlong File::fullread(int fd, FXuchar* ptr, FXlong len)
 {
     FXlong nread;
 #ifdef EINTR
@@ -235,7 +235,7 @@ FXlong File::fullread(int fd, unsigned char* ptr, FXlong len)
 
 
 // Write bytes
-FXlong File::fullwrite(int fd, const unsigned char* ptr, FXlong len)
+FXlong File::fullwrite(int fd, const FXuchar* ptr, FXlong len)
 {
     FXlong nwritten, ntotalwritten=0;
     while(len>0)
@@ -258,7 +258,7 @@ FXlong File::fullwrite(int fd, const unsigned char* ptr, FXlong len)
 
 
 // Construct overwrite dialog and get user answer
-unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
+FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 {
 	// Message string
 	FXString msg;
@@ -281,14 +281,22 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 		char buf[MAXPATHLEN];
 		if (S_ISDIR(linfo.st_mode)) // Folder
 		{
-			unsigned long long dirsize=0;
-			unsigned int nbfiles=0, nbsubfolders=0;
+			FXulong dirsize=0;
+			FXuint nbfiles=0, nbsubfolders=0;
 			strlcpy(buf,srcpath.text(),srcpath.length()+1);
 			dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
+#if __WORDSIZE == 64
+			snprintf(buf,sizeof(buf),"%lu",dirsize);
+#else
 			snprintf(buf,sizeof(buf),"%llu",dirsize);
+#endif
 		}
 		else // File
-			snprintf(buf,sizeof(buf),"%llu",(unsigned long long)linfo.st_size);					
+#if __WORDSIZE == 64
+			snprintf(buf,sizeof(buf),"%lu",(FXulong)linfo.st_size);					
+#else
+			snprintf(buf,sizeof(buf),"%llu",(FXulong)linfo.st_size);					
+#endif
 		srcsize=::hSize(buf);
 	}			
 	if (lstatrep(tgtpath.text(),&linfo)==0)
@@ -298,14 +306,22 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 		char buf[64];
 		if (S_ISDIR(linfo.st_mode)) // Folder
 		{
-			unsigned long long dirsize=0;
-			unsigned int nbfiles=0, nbsubfolders=0;
+			FXulong dirsize=0;
+			FXuint nbfiles=0, nbsubfolders=0;
 			strlcpy(buf,tgtpath.text(),tgtpath.length()+1);
 			dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
+#if __WORDSIZE == 64
+			snprintf(buf,sizeof(buf),"%lu",dirsize);
+#else
 			snprintf(buf,sizeof(buf),"%llu",dirsize);
+#endif
 		}
 		else // File
-			snprintf(buf,sizeof(buf),"%llu",(unsigned long long)linfo.st_size);					
+#if __WORDSIZE == 64
+			snprintf(buf,sizeof(buf),"%lu",(FXulong)linfo.st_size);					
+#else
+			snprintf(buf,sizeof(buf),"%llu",(FXulong)linfo.st_size);					
+#endif
 		tgtsize=::hSize(buf);
 	}			
 	
@@ -320,7 +336,7 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 	
 	// Overwrite dialog
 	OverwriteBox* dlg = new OverwriteBox(this,_("Confirm Overwrite"),msg);
-	unsigned int answer=dlg->execute(PLACEMENT_CURSOR);
+	FXuint answer=dlg->execute(PLACEMENT_CURSOR);
 	delete dlg;
 	restartTimeout();
 
@@ -332,7 +348,7 @@ unsigned int File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 int File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
 {
 	FXString destfile;
-	unsigned char buffer[32768];
+	FXuchar buffer[32768];
     struct stat info;
 	struct utimbuf timbuf;
     FXlong nread, nwritten;
@@ -372,7 +388,7 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
 						else
 							str.format(_("Can't copy file %s"),target.text());
 						mbox->setText(str);
-						unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -426,7 +442,7 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
 						else
 							str.format(_("Can't copy file %s"),target.text());
 						mbox->setText(str);
-						unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -459,7 +475,7 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
 						else
 							str.format(_("Can't preserve date when copying file %s"),target.text());
 						mbox->setText(str);
-						unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 						
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -498,7 +514,7 @@ int File::copyfile(const FXString& source, const FXString& target, const FXbool
 		else
 			str.format(_("Can't copy file %s"),target.text());
 		mbox->setText(str);
-		unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+		FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 		restartTimeout();
 		if(answer == BOX_CLICKED_CANCEL)
@@ -585,7 +601,7 @@ int File::copydir(const FXString& source,const FXString& target,struct stat& par
 						str.format(_("Can't copy file %s : Permission denied"),oldchild.text());
        				forceTimeout();
 					mbox->setText(str);
-					unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+					FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 					restartTimeout();
 					if(answer == BOX_CLICKED_CANCEL)
@@ -621,7 +637,7 @@ int File::copydir(const FXString& source,const FXString& target,struct stat& par
 				else
 					str.format(_("Can't preserve date when copying folder %s"),target.text());
 				mbox->setText(str);
-				unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
@@ -754,7 +770,7 @@ int File::copy(const FXString& source, const FXString& target, const FXbool conf
 			downlabel->setText(label);
 			getApp()->repaint();
 			forceTimeout();
-			unsigned int answer=getOverwriteAnswer(source,targetfile);
+			FXuint answer=getOverwriteAnswer(source,targetfile);
        		switch(answer)
        		{
 				// Cancel
@@ -875,7 +891,7 @@ int File::remove(const FXString& file)
 				else
 					str.format(_("Can't delete folder %s"),file.text());
 				mbox->setText(str);
-				unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
@@ -926,7 +942,7 @@ int File::remove(const FXString& file)
 				else
 					str.format(_("Can't delete file %s"),file.text());
 				mbox->setText(str);
-				unsigned int answer=mbox->execute(PLACEMENT_CURSOR);
+				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
@@ -970,7 +986,7 @@ int File::rename(const FXString& source, const FXString& target)
 		// Overwrite dialog if necessary
 		if (!(overwrite_all | skip_all))
     	{
-       		unsigned int answer=getOverwriteAnswer(source,target);
+       		FXuint answer=getOverwriteAnswer(source,target);
 			switch(answer)
        		{
 				// Cancel
@@ -1089,7 +1105,7 @@ int File::move(const FXString& source,const FXString& target,const FXbool restor
 		if (!overwrite_all & !skip_all)
 		{
 			forceTimeout();
-			unsigned int answer=getOverwriteAnswer(source,targetfile);
+			FXuint answer=getOverwriteAnswer(source,targetfile);
  			restartTimeout();
        		switch(answer)
        		{
@@ -1192,7 +1208,7 @@ int File::symlink(const FXString& source,const FXString& target)
 		// Overwrite dialog if necessary
 		if (!(overwrite_all | skip_all))
     	{
-			unsigned int answer=getOverwriteAnswer(source,targetfile);
+			FXuint answer=getOverwriteAnswer(source,targetfile);
        		switch(answer)
        		{
 				// Cancel
@@ -1618,7 +1634,7 @@ int File::archive(const FXString name, const FXString cmd)
 			FXString msg;
 			msg.format(_("File %s already exists. Overwrite?"),name.text());
        		OverwriteBox* dlg = new OverwriteBox(this,_("Confirm Overwrite"),msg);
-       		unsigned int answer=dlg->execute(PLACEMENT_CURSOR);
+       		FXuint answer=dlg->execute(PLACEMENT_CURSOR);
 			delete dlg;
        		switch(answer)
        		{
@@ -1664,7 +1680,7 @@ int File::archive(const FXString name, const FXString cmd)
 
 
 #if defined(linux)
-int File::mount(const FXString dir, const FXString msg, const FXString cmd, const unsigned int op)
+int File::mount(const FXString dir, const FXString msg, const FXString cmd, const FXuint op)
 {
 	FXbool mount_messages=getApp()->reg().readUnsignedEntry("OPTIONS","mount_messages",TRUE);
 
