@@ -61,9 +61,9 @@ protected:
 
 	void forceTimeout(void);
 	void restartTimeout(void);
-    FXlong fullread(int fd, unsigned char* ptr, FXlong len);
-    FXlong fullwrite(int fd, const unsigned char* ptr, FXlong len);
-	unsigned int getOverwriteAnswer(FXString, FXString);
+    FXlong fullread(int fd, FXuchar* ptr, FXlong len);
+    FXlong fullwrite(int fd, const FXuchar* ptr, FXlong len);
+	FXuint getOverwriteAnswer(FXString, FXString);
     int copyfile(const FXString& source, const FXString& target, const FXbool preserve_date);
 	int copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date);
     int copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes, const FXbool preserve_date);
@@ -83,7 +83,7 @@ public:
     {}
 	~File();
     void create();
-    File(FXWindow *owner, FXString title, const unsigned int operation);
+    File(FXWindow *owner, FXString title, const FXuint operation);
 
 	enum 
 	{
@@ -119,7 +119,7 @@ public:
 	int archive(const FXString name, const FXString cmd);
 
 #if defined(linux)
-	int mount(const FXString dir, const FXString msg, const FXString cmd, const  unsigned int op);
+	int mount(const FXString dir, const FXString msg, const FXString cmd, const  FXuint op);
 	int pkgInstall(const FXString name, const FXString cmd);
 	int pkgUninstall(const FXString name, const FXString cmd);
 #endif
