@@ -20,7 +20,7 @@
 #define FILESTYLEMASK (_ICONLIST_DETAILED|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_ROWS|_ICONLIST_COLUMNS|_ICONLIST_AUTOSIZE)
 
 // Single click navigation
-extern unsigned int single_click;
+extern FXuint single_click;
 
 // To allow keyboard scrolling in popup dialogs
 extern FXbool allowPopupScroll;
@@ -62,7 +62,7 @@ FXIMPLEMENT(FileSelector,FXPacker,FileSelectorMap,ARRAYNUMBER(FileSelectorMap))
 static const char allfiles[]="All Files (*)";
 
 // File selector object
-FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
+FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,int x,int y,int w,int h):
         FXPacker(p,opts,x,y,w,h,0,0,0,0,0,0)
 {
 	FXAccelTable *table=getShell()->getAccelTable();
@@ -79,7 +79,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned
     FXHorizontalFrame* pathframe=new FXHorizontalFrame(cont,LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0, 0,0);
 
  	// File list
- 	unsigned int options;
+ 	FXuint options;
 	FXbool smoothscroll=getApp()->reg().readUnsignedEntry("SETTINGS","smooth_scroll",TRUE);	
 	if (smoothscroll)
 		options=_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y;
@@ -101,7 +101,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned
     list->setHeaderSize(7,getApp()->reg().readUnsignedEntry("FILEDIALOG","attr_size",100));  	
 	
 	// Set file selector options
-	unsigned int listmode=getApp()->reg().readUnsignedEntry("FILEDIALOG","listmode",_ICONLIST_MINI_ICONS);
+	FXuint listmode=getApp()->reg().readUnsignedEntry("FILEDIALOG","listmode",_ICONLIST_MINI_ICONS);
 	FXbool hiddenfiles=getApp()->reg().readUnsignedEntry("FILEDIALOG","hiddenfiles",FALSE);
 	showHiddenFiles(hiddenfiles);
 	setFileBoxStyle	(listmode);
@@ -255,7 +255,7 @@ void FileSelector::create()
 // Double-clicked item in file list
 long FileSelector::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
 {
-    long index=(long)ptr;
+    FXlong index=(FXlong)ptr;
     if(index<0)
         return 1;
 
@@ -297,13 +297,13 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 {
 	if (single_click != SINGLE_CLICK_NONE)
 	{		
-		long index=(long)ptr;
+		FXlong index=(FXlong)ptr;
 		if(index<0)
 			return 1;
 
 		// In detailed mode, avoid single click when cursor is not over the first column
 		int x, y;
-		unsigned int state;
+		FXuint state;
 		getCursorPosition(x,y,state);
 		FXbool allow=TRUE;
 		if (!(list->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-list->getXPosition())>list->getHeaderSize(0))
@@ -347,7 +347,7 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 // Change in items which are selected
 long FileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr)
 {
-    long index=(long)ptr;
+    FXlong index=(FXlong)ptr;
     FXString text,file;
 
     if(selectmode==SELECT_FILE_MULTIPLE)
@@ -1207,7 +1207,7 @@ FXString FileSelector::getPattern() const
 // Set current file pattern from the list
 void FileSelector::setCurrentPattern(int patno)
 {
-	if ((unsigned int)patno >= (unsigned int)filefilter->getNumItems())
+	if ((FXuint)patno >= (FXuint)filefilter->getNumItems())
         fxerror("%s::setCurrentPattern: index out of range.\n",getClassName());
     filefilter->setCurrentItem(patno);
     list->setPattern(patternFromText(filefilter->getItemText(patno)));
@@ -1224,7 +1224,7 @@ int FileSelector::getCurrentPattern() const
 // Change pattern for pattern number patno
 void FileSelector::setPatternText(int patno,const FXString& text)
 {
-	if ((unsigned int)patno >= (unsigned int)filefilter->getNumItems())
+	if ((FXuint)patno >= (FXuint)filefilter->getNumItems())
         fxerror("%s::setPatternText: index out of range.\n",getClassName());
     filefilter->setItemText(patno,text);
     if(patno==filefilter->getCurrentItem())
@@ -1235,7 +1235,7 @@ void FileSelector::setPatternText(int patno,const FXString& text)
 // Return pattern text of pattern patno
 FXString FileSelector::getPatternText(int patno) const
 {
-	if ((unsigned int)patno >= (unsigned int)filefilter->getNumItems())
+	if ((FXuint)patno >= (FXuint)filefilter->getNumItems())
         fxerror("%s::getPatternText: index out of range.\n",getClassName());
     return filefilter->getItemText(patno);
 }
@@ -1256,14 +1256,14 @@ int FileSelector::getItemSpace() const
 
 
 // Change File List style
-void FileSelector::setFileBoxStyle(unsigned int style)
+void FileSelector::setFileBoxStyle(FXuint style)
 {
 	list->setListStyle((list->getListStyle()&~FILESTYLEMASK) | (style&FILESTYLEMASK));
 }
 
 
 // Return File List style
-unsigned int FileSelector::getFileBoxStyle() const
+FXuint FileSelector::getFileBoxStyle() const
 {
     return list->getListStyle()&FILESTYLEMASK;
 }
@@ -1271,7 +1271,7 @@ unsigned int FileSelector::getFileBoxStyle() const
 
 
 // Change file selection mode
-void FileSelector::setSelectMode(unsigned int mode)
+void FileSelector::setSelectMode(FXuint mode)
 {
     switch(mode)
     {
@@ -1402,7 +1402,7 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
     // Popup menu pane
 	FXMenuPane menu(this);
     int x,y;
-    unsigned int state;
+    FXuint state;
     getRoot()->getCursorPosition(x,y,state);
 
 	new FXMenuCommand(&menu,_("Go ho&me"),homeicon,this,ID_HOME);
@@ -1449,7 +1449,7 @@ FXIMPLEMENT(FileDialog,DialogBox,NULL,0)
 
 
 // File Dialog object
-FileDialog::FileDialog(FXWindow* owner,const FXString& name,unsigned int opts,int x,int y,int w,int h):
+FileDialog::FileDialog(FXWindow* owner,const FXString& name,FXuint opts,int x,int y,int w,int h):
         DialogBox(owner,name,opts|DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,x,y,w,h,0,0,0,0,4,4)
 {
     list=new FileSelector(this,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -1459,8 +1459,8 @@ FileDialog::FileDialog(FXWindow* owner,const FXString& name,unsigned int opts,in
     list->cancelButton()->setSelector(DialogBox::ID_CANCEL);
     
     // Set file dialog options 
-	unsigned int width=getApp()->reg().readUnsignedEntry("FILEDIALOG","width",640);
-	unsigned int height=getApp()->reg().readUnsignedEntry("FILEDIALOG","height",480);
+	FXuint width=getApp()->reg().readUnsignedEntry("FILEDIALOG","width",640);
+	FXuint height=getApp()->reg().readUnsignedEntry("FILEDIALOG","height",480);
 	setWidth(width);
 	setHeight(height);
 }
@@ -1576,28 +1576,28 @@ int FileDialog::getItemSpace() const
 
 
 // Change File List style
-void FileDialog::setFileBoxStyle(unsigned int style)
+void FileDialog::setFileBoxStyle(FXuint style)
 {
     list->setFileBoxStyle(style);
 }
 
 
 // Return File List style
-unsigned int FileDialog::getFileBoxStyle() const
+FXuint FileDialog::getFileBoxStyle() const
 {
     return list->getFileBoxStyle();
 }
 
 
 // Change file selection mode
-void FileDialog::setSelectMode(unsigned int mode)
+void FileDialog::setSelectMode(FXuint mode)
 {
     list->setSelectMode(mode);
 }
 
 
 // Return file selection mode
-unsigned int FileDialog::getSelectMode() const
+FXuint FileDialog::getSelectMode() const
 {
     return list->getSelectMode();
 }
