@@ -31,7 +31,7 @@ protected:
     FXCheckButton *readonly;        // Open file as read only
     FXButton      *accept;          // Accept button
     FXButton      *cancel;          // Cancel button
-    unsigned int         selectmode;      // Select mode
+    FXuint         selectmode;      // Select mode
 	FXArrowButton   *btnbackhist;     // Back history
 	FXArrowButton   *btnforwardhist;  // Forward history
     PathLinker*		  pathlink;
@@ -86,7 +86,7 @@ public:
 public:
 
     // Constructor
-    FileSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
+    FileSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Return a pointer to the "Accept" button
     FXButton *acceptButton() const
@@ -165,16 +165,16 @@ public:
     int getItemSpace() const;
 
     // Change file list style
-    void setFileBoxStyle(unsigned int style);
+    void setFileBoxStyle(FXuint style);
 
     // Return file list style
-    unsigned int getFileBoxStyle() const;
+    FXuint getFileBoxStyle() const;
 
     // Change file selection mode
-    void setSelectMode(unsigned int mode);
+    void setSelectMode(FXuint mode);
 
     // Return file selection mode
-    unsigned int getSelectMode() const
+    FXuint getSelectMode() const
     {
         return selectmode;
     }
@@ -223,7 +223,7 @@ private:
 public:
 
     // Construct File Dialog Box
-    FileDialog(FXWindow* owner,const FXString& name,unsigned int opts=0,int x=0,int y=0,int w=500,int h=300);
+    FileDialog(FXWindow* owner,const FXString& name,FXuint opts=0,int x=0,int y=0,int w=500,int h=300);
 
     // Change file name
     void setFilename(const FXString& path);
@@ -288,16 +288,16 @@ public:
     int getItemSpace() const;
 
     // Change File List style
-    void setFileBoxStyle(unsigned int style);
+    void setFileBoxStyle(FXuint style);
 
     // Return File List style
-    unsigned int getFileBoxStyle() const;
+    FXuint getFileBoxStyle() const;
 
     // Change file selection mode
-    void setSelectMode(unsigned int mode);
+    void setSelectMode(FXuint mode);
 
     // Return file selection mode
-    unsigned int getSelectMode() const;
+    FXuint getSelectMode() const;
 
     // Show readonly button
     void showReadOnly(FXbool show);
