@@ -22,7 +22,7 @@ FXIMPLEMENT(IconDict,FXDict,NULL,0)
 
 
 // Default icon path
-const FXchar IconDict::defaultIconPath[]=DEFAULTICONPATH;
+const char IconDict::defaultIconPath[]=DEFAULTICONPATH;
 
 
 // Build icon table
@@ -74,9 +74,9 @@ IconDict::~IconDict()
 
 
 // These registry keys are used for default bindings.
-const FXchar FileDict::defaultExecBinding[]="defaultexecbinding";
-const FXchar FileDict::defaultDirBinding[]="defaultdirbinding";
-const FXchar FileDict::defaultFileBinding[]="defaultfilebinding";
+const char FileDict::defaultExecBinding[]="defaultexecbinding";
+const char FileDict::defaultDirBinding[]="defaultdirbinding";
+const char FileDict::defaultFileBinding[]="defaultfilebinding";
 
 
 // Object implementation
@@ -100,15 +100,15 @@ FileDict::FileDict(FXApp* a,FXSettings* db):app(a),settings(db)
 // Create new association from extension
 void *FileDict::createData(const void* ptr)
 {
-	register const FXchar *p=(const FXchar*)ptr;
-    register FXchar *q;
-    FXchar command[COMMANDLEN];
-    FXchar extension[EXTENSIONLEN];
-    FXchar mimetype[MIMETYPELEN];
-    FXchar bigname[ICONNAMELEN];
-    FXchar bignameopen[ICONNAMELEN];
-    FXchar mininame[ICONNAMELEN];
-    FXchar mininameopen[ICONNAMELEN];
+	register const char *p=(const char*)ptr;
+    register char *q;
+    char command[COMMANDLEN];
+    char extension[EXTENSIONLEN];
+    char mimetype[MIMETYPELEN];
+    char bigname[ICONNAMELEN];
+    char bignameopen[ICONNAMELEN];
+    char mininame[ICONNAMELEN];
+    char mininameopen[ICONNAMELEN];
     FileAssoc *fileassoc;
 
 	// Make association record
@@ -228,7 +228,7 @@ FXString FileDict::getIconPath() const
 
 
 // Replace or add file association
-FileAssoc* FileDict::replace(const FXchar* ext,const FXchar* str)
+FileAssoc* FileDict::replace(const char* ext,const char* str)
 {
     // Replace entry in registry
     settings->writeStringEntry("FILETYPES",ext,str);
@@ -239,7 +239,7 @@ FileAssoc* FileDict::replace(const FXchar* ext,const FXchar* str)
 
 
 // Remove file association
-FileAssoc* FileDict::remove(const FXchar* ext)
+FileAssoc* FileDict::remove(const char* ext)
 {
 	// Delete registry entry for this type
     settings->deleteEntry("FILETYPES",ext);
@@ -252,11 +252,11 @@ FileAssoc* FileDict::remove(const FXchar* ext)
 
 
 // Find file association using the lower case file extension
-FileAssoc* FileDict::associate(const FXchar* key)
+FileAssoc* FileDict::associate(const char* key)
 {
-    register const FXchar* association;
+    register const char* association;
     register FileAssoc* record;
-	register FXchar lowkey[MAXPATHLEN];
+	register char lowkey[MAXPATHLEN];
 	
 	// Convert the association key to lower case
 	// Uses these functions because they seem to be faster than FXString
@@ -287,10 +287,10 @@ FileAssoc* FileDict::associate(const FXchar* key)
 
 
 // Find file association from registry
-FileAssoc* FileDict::findFileBinding(const FXchar* pathname)
+FileAssoc* FileDict::findFileBinding(const char* pathname)
 {
-    register const FXchar *filename=pathname;
-    register const FXchar *p=pathname;
+    register const char *filename=pathname;
+    register const char *p=pathname;
     register FileAssoc* record;
 	
     while(*p)
@@ -323,9 +323,9 @@ FileAssoc* FileDict::findFileBinding(const FXchar* pathname)
 
 
 // Find directory association from registry
-FileAssoc* FileDict::findDirBinding(const FXchar* pathname)
+FileAssoc* FileDict::findDirBinding(const char* pathname)
 {
-    register const FXchar* path=pathname;
+    register const char* path=pathname;
     register FileAssoc* record;
     while(*path)
     {
@@ -341,7 +341,7 @@ FileAssoc* FileDict::findDirBinding(const FXchar* pathname)
 
 
 // Find executable association from registry
-FileAssoc* FileDict::findExecBinding(const FXchar* pathname)
+FileAssoc* FileDict::findExecBinding(const char* pathname)
 {
     return associate(defaultExecBinding);
 }
