@@ -15,7 +15,7 @@ struct FileAssoc
     FXIcon    *miniicon;          // Mini normal icon
     FXIcon    *miniiconopen;      // Mini open icon
     FXDragType dragtype;          // Registered drag type
-    unsigned int     flags;             // Flags
+    FXuint     flags;             // Flags
 };
 
 
