@@ -22,6 +22,7 @@ class FXAPI FileItem : public IconItem
 {
     FXDECLARE(FileItem)
     friend class FileList;
+    friend class SearchPanel;
 protected:
     FileAssoc  *assoc;                      // File association record
 	FileItem   *link;                   	// Link to next item
@@ -129,9 +130,9 @@ protected:
     FXString     dragfiles;             // Dragged files
     FileDict	*associations;          // Association table
     FXString     pattern;               // Pattern of file names
-    unsigned int       matchmode;             // File wildcard match mode
+    FXuint       matchmode;       // File wildcard match mode
     FXTime       timestamp;             // Time when last refreshed
-	unsigned int       counter;               // Refresh counter
+	FXuint       counter;         // Refresh counter
 	FXbool		allowrefresh;			// Allow or disallow periodic refresh
 	FXbool		displaythumbnails;		// Display thumbnails
 	FXString	trashfileslocation;     // Location of the trash files directory
@@ -141,7 +142,6 @@ protected:
 	int		deldatesize;
 	int		origpathsize;
 	FXWindow	*focuswindow;			// Window used to test focus
-
 public:
 	StringList		*backhist;          // Back history
 	StringList		*forwardhist;       // Forward history
@@ -215,6 +215,8 @@ public:
 	long onCmdDragReject(FXObject* sender,FXSelector,void*);
 	long onUpdRefreshTimer(FXObject* sender,FXSelector,void*);
 public:
+    static int compare(const IconItem* pa,const IconItem* pb,
+                       bool igncase,  bool asc, bool mixdir, int jmp);
 	static int ascending(const IconItem* pa,const IconItem* pb);
 	static int descending(const IconItem* pa,const IconItem* pb);
 	static int ascendingCase(const IconItem* pa,const IconItem* pb);
@@ -303,7 +305,7 @@ public:
 public:
 
     // Construct a file list
-    FileList(FXWindow* focuswin, FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXbool showthumbs=FALSE,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
+    FileList(FXWindow* focuswin, FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXbool showthumbs=FALSE,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
@@ -372,12 +374,6 @@ public:
 		(*index)=itm;
 		return num;
 	}
-
-	// Return number of selected items
-	//int getNumSelectedItems(void) const;
-
-	// Return number of selected items and index of first selected item  
-	//int getNumSelectedItems(int *index) const;
 	
 	// Return name of item at index
     FXString getItemFilename(int index) const;
@@ -395,7 +391,7 @@ public:
 	FXulong getItemFileSize(int index) const;
 
     // Return wildcard matching mode
-    unsigned int getMatchMode() const
+    FXuint getMatchMode() const
     {
         return matchmode;
     }
@@ -420,7 +416,7 @@ public:
 	void setAllowRefresh(const FXbool allow);
 
     // Change wildcard matching mode
-    void setMatchMode(unsigned int mode);
+    void setMatchMode(FXuint mode);
 
     // Return TRUE if showing hidden files
     FXbool shownHiddenFiles() const;
