@@ -33,7 +33,7 @@ FXDEFMAP(FontSelector) FontSelectorMap[]=
 FXIMPLEMENT(FontSelector,FXPacker,FontSelectorMap,ARRAYNUMBER(FontSelectorMap))
 
 
-FontSelector::FontSelector(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
+FontSelector::FontSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,int x,int y,int w,int h):
         FXPacker(p,opts,x,y,w,h)
 {
     target=tgt;
@@ -175,7 +175,7 @@ void FontSelector::create()
 void FontSelector::listFontFaces()
 {
     FXFontDesc *fonts;
-    unsigned int numfonts,f;
+    FXuint numfonts,f;
     int selindex=-1;
     familylist->clearItems();
     family->setText("");
@@ -204,7 +204,7 @@ void FontSelector::listFontFaces()
 void FontSelector::listWeights()
 {
     FXFontDesc *fonts;
-    unsigned int numfonts,f,ww,lastww;
+    FXuint numfonts,f,ww,lastww;
     const char *wgt;
     int selindex=-1;
     weightlist->clearItems();
@@ -268,7 +268,7 @@ void FontSelector::listWeights()
             weightlist->setCurrentItem(selindex);
             weightlist->makeItemVisible(selindex);
             weight->setText(weightlist->getItemText(selindex));
-            selected.weight=(unsigned int)(FXuval)weightlist->getItemData(selindex);
+            selected.weight=(FXuint)(FXuval)weightlist->getItemData(selindex);
         }
         FXFREE(&fonts);
     }
@@ -279,7 +279,7 @@ void FontSelector::listWeights()
 void FontSelector::listSlants()
 {
     FXFontDesc *fonts;
-    unsigned int numfonts,f,s,lasts;
+    FXuint numfonts,f,s,lasts;
     const char *slt;
     int selindex=-1;
     stylelist->clearItems();
@@ -331,7 +331,7 @@ void FontSelector::listSlants()
             stylelist->setCurrentItem(selindex);
             stylelist->makeItemVisible(selindex);
             style->setText(stylelist->getItemText(selindex));
-            selected.slant=(unsigned int)(FXuval)stylelist->getItemData(selindex);
+            selected.slant=(FXuint)(FXuval)stylelist->getItemData(selindex);
         }
         FXFREE(&fonts);
     }
@@ -341,12 +341,12 @@ void FontSelector::listSlants()
 // Fill the list with font sizes
 void FontSelector::listFontSizes()
 {
-    const unsigned int sizeint[]=
+    const FXuint sizeint[]=
         {
             60,80,90,100,110,120,140,160,200,240,300,360,420,480,640
         };
     FXFontDesc *fonts;
-    unsigned int numfonts,f,s,lasts;
+    FXuint numfonts,f,s,lasts;
     int selindex=-1;
     sizelist->clearItems();
     size->setText("");
@@ -386,7 +386,7 @@ void FontSelector::listFontSizes()
             sizelist->setCurrentItem(selindex);
             sizelist->makeItemVisible(selindex);
             size->setText(sizelist->getItemText(selindex));
-            selected.size=(unsigned int)(FXuval)sizelist->getItemData(selindex);
+            selected.size=(FXuint)(FXuval)sizelist->getItemData(selindex);
         }
         FXFREE(&fonts);
     }
@@ -431,7 +431,7 @@ long FontSelector::onCmdFamily(FXObject*,FXSelector,void* ptr)
 // Changed weight setting
 long FontSelector::onCmdWeight(FXObject*,FXSelector,void* ptr)
 {
-    selected.weight=(unsigned int)(FXuval)weightlist->getItemData((int)(FXival)ptr);
+    selected.weight=(FXuint)(FXuval)weightlist->getItemData((int)(FXival)ptr);
     weight->setText(weightlist->getItemText((int)(FXival)ptr));
     listSlants();
     listFontSizes();
@@ -443,7 +443,7 @@ long FontSelector::onCmdWeight(FXObject*,FXSelector,void* ptr)
 // User clicked up directory button
 long FontSelector::onCmdSize(FXObject*,FXSelector,void* ptr)
 {
-    selected.size=(unsigned int)(FXuval)sizelist->getItemData((int)(FXival)ptr);
+    selected.size=(FXuint)(FXuval)sizelist->getItemData((int)(FXival)ptr);
     size->setText(sizelist->getItemText((int)(FXival)ptr));
     previewFont();
     return 1;
@@ -453,7 +453,7 @@ long FontSelector::onCmdSize(FXObject*,FXSelector,void* ptr)
 // User clicked up directory button
 long FontSelector::onCmdSizeText(FXObject*,FXSelector,void*)
 {
-    selected.size=(unsigned int)(10.0*FXFloatVal(size->getText()));
+    selected.size=(FXuint)(10.0*FXFloatVal(size->getText()));
     if(selected.size<60) selected.size=60;
     if(selected.size>2400) selected.size=2400;
     previewFont();
@@ -464,7 +464,7 @@ long FontSelector::onCmdSizeText(FXObject*,FXSelector,void*)
 // User clicked up directory button
 long FontSelector::onCmdStyle(FXObject*,FXSelector,void* ptr)
 {
-    selected.slant=(unsigned int)(FXuval)stylelist->getItemData((int)(FXival)ptr);
+    selected.slant=(FXuint)(FXuval)stylelist->getItemData((int)(FXival)ptr);
     style->setText(stylelist->getItemText((int)(FXival)ptr));
     listFontSizes();
     previewFont();
@@ -483,7 +483,7 @@ long FontSelector::onCmdStyleText(FXObject*,FXSelector,void*)
 long FontSelector::onCmdCharset(FXObject*,FXSelector,void*)
 {
     int index=charset->getCurrentItem();
-    unsigned int enc=(unsigned int)(FXuval)charset->getItemData(index);
+    FXuint enc=(FXuint)(FXuval)charset->getItemData(index);
     selected.encoding=(FXFontEncoding)enc;
     listFontFaces();
     listWeights();
@@ -506,7 +506,7 @@ long FontSelector::onUpdCharset(FXObject*,FXSelector,void*)
 long FontSelector::onCmdSetWidth(FXObject*,FXSelector,void*)
 {
     int index=setwidth->getCurrentItem();
-    selected.setwidth=(unsigned int)(FXuval)setwidth->getItemData(index);
+    selected.setwidth=(FXuint)(FXuval)setwidth->getItemData(index);
     listFontFaces();
     listWeights();
     listSlants();
@@ -529,7 +529,7 @@ long FontSelector::onCmdPitch(FXObject*,FXSelector,void*)
 {
     int index=pitch->getCurrentItem();
     selected.flags&=~(FXFont::Fixed|FXFont::Variable);
-    selected.flags|=(unsigned int)(FXuval)pitch->getItemData(index);
+    selected.flags|=(FXuint)(FXuval)pitch->getItemData(index);
     listFontFaces();
     listWeights();
     listSlants();
@@ -716,7 +716,7 @@ FXIMPLEMENT(FontDialog,DialogBox,NULL,0)
 
 
 // Separator item
-FontDialog::FontDialog(FXWindow* owner,const FXString& name,unsigned int opts,int x,int y,int w,int h):
+FontDialog::FontDialog(FXWindow* owner,const FXString& name,FXuint opts,int x,int y,int w,int h):
         DialogBox(owner,name,opts|DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,x,y,w,h,0,0,0,0,4,4)
 {
     fontbox=new FontSelector(this,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y);
