@@ -74,7 +74,7 @@ public:
 public:
 
     // Constructor
-    FontSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=0,int x=0,int y=0,int w=0,int h=0);
+    FontSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
@@ -123,7 +123,7 @@ private:
     FontDialog &operator=(const FontDialog&);
 public:
     // Constructor
-    FontDialog(FXWindow* owner,const FXString& name,unsigned int opts=0,int x=0,int y=0,int w=750,int h=480);
+    FontDialog(FXWindow* owner,const FXString& name,FXuint opts=0,int x=0,int y=0,int w=750,int h=480);
 
     // Save dialog to a stream
     virtual void save(FXStream& store) const;
