@@ -32,7 +32,7 @@ public:
 		field->onCmdCursorEnd(0,0,0);
         field->setFocus();
 	}
-    ComboBox(FXComposite *p,int cols,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=COMBOBOX_NORMAL);
+    ComboBox(FXComposite *p,int cols,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=COMBOBOX_NORMAL);
     virtual void create();
 };
 
@@ -46,7 +46,7 @@ protected:
     ComboBox*          input;
     FXLabel*           label;
     FXDataTarget*      string_target;
-	unsigned int			   browsetype;
+	FXuint			   browsetype;
 	FXString           initialdir;
 private:
     HistInputDialog()
@@ -58,7 +58,7 @@ public:
         ID_BROWSE_PATH=DialogBox::ID_LAST,
         ID_LAST
     };
-    HistInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, unsigned int browse=HIST_INPUT_FILE, FXbool option=FALSE, FXString=FXString::null);
+    HistInputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *ic=NULL, FXuint browse=HIST_INPUT_FILE, FXbool option=FALSE, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
 	long onCmdBrowsePath(FXObject*,FXSelector,void*);
