@@ -36,7 +36,7 @@
 #define SELECT_MASK   (_ICONLIST_EXTENDEDSELECT|_ICONLIST_SINGLESELECT|_ICONLIST_BROWSESELECT|_ICONLIST_MULTIPLESELECT)
 #define ICONLIST_MASK (SELECT_MASK|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_COLUMNS|_ICONLIST_SEARCH|_ICONLIST_STANDARD|_ICONLIST_AUTOSIZE)
 
-extern unsigned int single_click;
+extern FXuint single_click;
 extern FXbool file_tooltips;
 extern FXbool relative_resize;
 
@@ -54,7 +54,7 @@ inline FXbool IconItem::isOdd(int i) const
 // Draw item
 void IconItem::draw(IconList* list,FXDC& dc,int x,int y,int w,int h) const
 {
-    register unsigned int options=list->getListStyle();
+    register FXuint options=list->getListStyle();
     if (options&_ICONLIST_BIG_ICONS)
     	drawBigIcon(list,dc,x,y,w,h);
     else if (options&_ICONLIST_MINI_ICONS)
@@ -133,6 +133,7 @@ void IconItem::drawMiniIcon(const IconList* list,FXDC& dc,int x,int y,int w,int
     register int len,dw,s,space;
     x+=SIDE_SPACING/2;
     space=w-SIDE_SPACING;
+ 
     if (miniIcon)
     {
         iw=miniIcon->getWidth();
@@ -191,7 +192,7 @@ void IconItem::drawDetails(IconList* list,FXDC& dc,int x,int y,int,int h) const
     register FXFont *font=list->getFont();
     register int iw=0,ih=0,tw=0,th=0,yt,beg,end,hi,drw,space,used,dw,xx,dx=0;
 	register FXbool highlight;
-	register unsigned int options=list->getListStyle();
+	register FXuint options=list->getListStyle();
 
     if (header->getNumItems()==0)
         return;
@@ -302,7 +303,7 @@ void IconItem::drawDetails(IconList* list,FXDC& dc,int x,int y,int,int h) const
 int IconItem::hitItem(const IconList* list,int rx,int ry,int rw,int rh) const
 {
     register int iw=0,tw=0,ih=0,th=0,ss=0,ix,iy,tx,ty,w,h,sp,tlen;
-    register unsigned int options=list->getListStyle();
+    register FXuint options=list->getListStyle();
     register FXFont *font=list->getFont();
     for (tlen=0; tlen<label.length() && label[tlen]!='\t'; tlen++);
     if (options&_ICONLIST_BIG_ICONS)
@@ -492,7 +493,7 @@ void IconItem::detach()
 // Get item width
 int IconItem::getWidth(const IconList* list) const
 {
-    register unsigned int options=list->getListStyle();
+    register FXuint options=list->getListStyle();
     register FXFont *font=list->getFont();
     register int iw=0,tw=0,w=0,tlen;
     for (tlen=0; tlen<label.length() && label[tlen]!='\t'; tlen++);
@@ -523,7 +524,7 @@ int IconItem::getWidth(const IconList* list) const
 // Get item height
 int IconItem::getHeight(const IconList* list) const
 {
-    register unsigned int options=list->getListStyle();
+    register FXuint options=list->getListStyle();
     register int ih=0,th=0,h=0;
     if (options&_ICONLIST_BIG_ICONS)
     {
@@ -646,7 +647,7 @@ FXIMPLEMENT(IconList,FXScrollArea,IconListMap,ARRAYNUMBER(IconListMap))
 
 
 // Icon List
-IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h):
+IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,int x,int y,int w,int h):
                    FXScrollArea(p,opts,x,y,w,h)
 {
 	//autosize=opts&_ICONLIST_AUTOSIZE; // Workaround for a bug (?)
@@ -677,14 +678,14 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,unsigned int opts
 
 	// Sort colors for detailed mode
 	FXColor listbackColor=getApp()->reg().readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
-	unsigned int R, G, B;
-	R=(unsigned int)(DARKEN_SORT*FXREDVAL(listbackColor));
-	G=(unsigned int)(DARKEN_SORT*FXGREENVAL(listbackColor));
-	B=(unsigned int)(DARKEN_SORT*FXBLUEVAL(listbackColor));
+	FXuint R, G, B;
+	R=(FXuint)(DARKEN_SORT*FXREDVAL(listbackColor));
+	G=(FXuint)(DARKEN_SORT*FXGREENVAL(listbackColor));
+	B=(FXuint)(DARKEN_SORT*FXBLUEVAL(listbackColor));
 	sortColor=FXRGB(R,G,B);
-	R=(unsigned int)(DARKEN_SORT*FXREDVAL(highlightColor));
-	G=(unsigned int)(DARKEN_SORT*FXGREENVAL(highlightColor));
-	B=(unsigned int)(DARKEN_SORT*FXBLUEVAL(highlightColor));
+	R=(FXuint)(DARKEN_SORT*FXREDVAL(highlightColor));
+	G=(FXuint)(DARKEN_SORT*FXGREENVAL(highlightColor));
+	B=(FXuint)(DARKEN_SORT*FXBLUEVAL(highlightColor));
 	highlightSortColor=FXRGB(R,G,B);
 
 	itemSpace=ITEM_SPACE;
@@ -1474,8 +1475,8 @@ int IconList::getItemAt(int x,int y)
 // Compare strings up to n
 static int comp(const FXString& s1,const FXString& s2,int n)
 {
-    register const unsigned char *p1=(const unsigned char *)s1.text();
-    register const unsigned char *p2=(const unsigned char *)s2.text();
+    register const FXuchar *p1=(const FXuchar *)s1.text();
+    register const FXuchar *p2=(const FXuchar *)s2.text();
     register int c1,c2;
     if (0<n)
     {
@@ -1498,8 +1499,8 @@ static int comp(const FXString& s1,const FXString& s2,int n)
 // Compare strings case insensitive up to n
 static int compcase(const FXString& s1,const FXString& s2,int n)
 {
-    register const unsigned char *p1=(const unsigned char *)s1.text();
-    register const unsigned char *p2=(const unsigned char *)s2.text();
+    register const FXuchar *p1=(const FXuchar *)s1.text();
+    register const FXuchar *p2=(const FXuchar *)s2.text();
     register int c1,c2;
     if (0<n)
     {
@@ -1523,7 +1524,7 @@ typedef int (*FXCompareFunc)(const FXString&,const FXString&,int);
 
 
 // Get item by name
-int IconList::findItem(const FXString& text,int start,unsigned int flgs) const
+int IconList::findItem(const FXString& text,int start,FXuint flgs) const
 {
     register FXCompareFunc comparefunc;
     register int index,len;
@@ -1571,7 +1572,7 @@ int IconList::findItem(const FXString& text,int start,unsigned int flgs) const
 
 
 // Get item by data
-int IconList::findItemByData(const void *ptr,int start,unsigned int flgs) const
+int IconList::findItemByData(const void *ptr,int start,FXuint flgs) const
 {
     register int index;
     if (0<items.no())
@@ -2146,10 +2147,14 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 				if (type==_("Folder") || type==_("Mount point"))
 				{
 					// Compute root file size
-					unsigned long long dnsize;
+					FXulong dnsize;
 					char dsize[64];
 					dnsize=::dirsize(pathname.text());
+#if __WORDSIZE == 64
+					snprintf(dsize,sizeof(dsize)-1,"%lu",dnsize);
+#else
 					snprintf(dsize,sizeof(dsize)-1,"%llu",dnsize);
+#endif
 					size=::hSize(dsize);
 					
 					if (deldate.empty())
@@ -2281,9 +2286,7 @@ long IconList::onPaint(FXObject*,FXSelector,void* ptr)
 					dc.setForeground(backColor);
                     dc.fillRectangle(x,y,itemSpace,itemHeight);
                     if (index<items.no())
-                    {
                         items[index]->draw(this,dc,x,y,itemSpace,itemHeight);
-                    }
                 }
             }
         }
@@ -2301,9 +2304,7 @@ long IconList::onPaint(FXObject*,FXSelector,void* ptr)
                     dc.setForeground(backColor);
                     dc.fillRectangle(x,y,itemSpace,itemHeight);
                     if (index<items.no())
-                    {
                         items[index]->draw(this,dc,x,y,itemSpace,itemHeight);
-                    }
                 }
             }
         }
@@ -2520,8 +2521,8 @@ int IconList::compareSection(const char *p,const char* q,int s)
     for (x=s; x && *q; x-=(*q++=='\t'));
     do
     {
-        c1=(unsigned char)(*p++);
-        c2=(unsigned char)(*q++);
+        c1=(FXuchar)(*p++);
+        c2=(FXuchar)(*q++);
     }
     while ('\t'<c1 && (c1==c2));
     return c1-c2;
@@ -2862,7 +2863,7 @@ hop:
             handle(this,FXSEL(SEL_COMMAND,0),(void*)(FXival)current);
         return 1;
     default:
-        if ((unsigned char)event->text[0]<' ')
+        if ((FXuchar)event->text[0]<' ')
             return 0;
         if (event->state&(CONTROLMASK|ALTMASK))
             return 0;
@@ -2979,7 +2980,7 @@ long IconList::onMotion(FXObject*,FXSelector,void* ptr)
     int olx,orx,oty,oby,nlx,nrx,nty,nby;
     FXEvent* event=(FXEvent*)ptr;
     int oldcursor=cursor;
-    unsigned int flg=flags;
+    FXuint flg=flags;
 
     // Kill the tip
     flags&=~FLAG_TIP;
@@ -3159,7 +3160,7 @@ long IconList::onLeftBtnPress(FXObject*,FXSelector,void* ptr)
 long IconList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr)
 {
     FXEvent* event=(FXEvent*)ptr;
-    unsigned int flg=flags;
+    FXuint flg=flags;
     if (isEnabled())
     {
         ungrab();
@@ -3814,9 +3815,9 @@ void IconList::setItemSpace(int s)
 
 
 // Change list style
-void IconList::setListStyle(unsigned int style)
+void IconList::setListStyle(FXuint style)
 {
-    unsigned int opts=(options&~ICONLIST_MASK) | (style&ICONLIST_MASK);
+    FXuint opts=(options&~ICONLIST_MASK) | (style&ICONLIST_MASK);
     if (options!=opts)
     {
         options=opts;
@@ -3826,7 +3827,7 @@ void IconList::setListStyle(unsigned int style)
 
 
 // Get list style
-unsigned int IconList::getListStyle() const
+FXuint IconList::getListStyle() const
 {
     return (options&ICONLIST_MASK);
 }
