@@ -40,7 +40,7 @@ protected:
     FXIcon   *bigIcon;    // Icon of item
     FXIcon   *miniIcon;   // Icon of item
     void     *data;       // Item user data pointer
-    unsigned int    state;      // Item state flags
+    FXuint    state;      // Item state flags
 private:
     IconItem(const IconItem&);
     IconItem& operator=(const IconItem&);
@@ -230,7 +230,7 @@ protected:
     FXString           help;              // Help text
     FXbool             state;             // State of item
 	FXbool			   allowTooltip;      // Allow tooltip in single click mode
-	unsigned int			   numsortheader;     // Index of the sorted column
+	FXuint			   numsortheader;     // Index of the sorted column
 	double           headerpct[10];     // Header sizes, relatively to the list width (in percent)
 	int			   count;             // Counter used to properly initialize the relative header sizes
 	FXbool 			   autosize;
@@ -319,7 +319,7 @@ public:
 public:
 
     // Construct icon list with no items in it initially
-    IconList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=_ICONLIST_NORMAL,int x=0,int y=0,int w=0,int h=0);
+    IconList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=_ICONLIST_NORMAL,int x=0,int y=0,int w=0,int h=0);
 
     // Create server-side resources
     virtual void create();
@@ -492,7 +492,7 @@ public:
 	// The option SEARCH_IGNORECASE causes a case-insensitive match.  Finally,
 	// passing SEARCH_PREFIX causes searching for a prefix of the item name.
 	// Return -1 if no matching item is found.
-    int findItem(const FXString& text,int start=-1,unsigned int flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+    int findItem(const FXString& text,int start=-1,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
 
    
     // Search items by associated user data, beginning from item start. If the
@@ -500,7 +500,7 @@ public:
     // Flags may be SEARCH_FORWARD or SEARCH_BACKWARD to control the
     // search direction; this can be combined with SEARCH_NOWRAP or SEARCH_WRAP
     // to control whether the search wraps at the start or end of the list.
-    int findItemByData(const void *ptr,int start=-1,unsigned int flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+    int findItemByData(const void *ptr,int start=-1,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
 
     // Scroll to make item at index visible
     virtual void makeItemVisible(int index);
@@ -532,7 +532,7 @@ public:
 	// Return TRUE if item is selected
 	FXbool isItemSelected(int index) const
 	{
-		if ((unsigned int)index >= (unsigned int)items.no())
+		if ((FXuint)index >= (FXuint)items.no())
 			fxerror("%s::isItemSelected: index out of range.\n",getClassName());
 		return items[index]->isSelected();
 	}
@@ -616,13 +616,13 @@ public:
     }
 
 	// Set sort header
-	void setSortHeader(const unsigned int num)
+	void setSortHeader(const FXuint num)
 	{
 		numsortheader=num;
 	}
 	
 	// Get sort header
-	unsigned int getSortHeader()
+	FXuint getSortHeader()
 	{
 		return numsortheader;
 	}
@@ -692,10 +692,10 @@ public:
     }
 
     // Get the current icon list style
-    unsigned int getListStyle() const;
+    FXuint getListStyle() const;
 
     // Set the current icon list style.
-    void setListStyle(unsigned int style);
+    void setListStyle(FXuint style);
 
     // Set the status line help text for this widget
     void setHelpText(const FXString& text);
