@@ -18,7 +18,7 @@ private:
         ;
     }
 public:
-    InputDialog(FXWindow*,FXString&,FXString,FXString,FXString label="",FXIcon *ic=NULL, int option=0, FXString=FXString::null);
+    InputDialog(FXWindow*,FXString,FXString,FXString,FXString label="",FXIcon *icon=NULL, FXbool option=FALSE, FXString=FXString::null);
     virtual void create();
     long onCmdKeyPress(FXObject*,FXSelector,void*);
     FXString getText()
