@@ -108,8 +108,8 @@ KeybindingsBox::KeybindingsBox(FXWindow *win, FXStringDict* glbbindings, FXStrin
 	xfwBindingsList=new IconList(frame4,this,ID_XFW_BINDINGS_LIST,_ICONLIST_STANDARD|HSCROLLER_NEVER|ICONLIST_BROWSESELECT|LAYOUT_SIDE_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     // Set list headers name and size 
-	unsigned int hsize1=getWidth()/2-50;
-	unsigned int hsize2=getWidth()/4;
+	FXuint hsize1=getWidth()/2-50;
+	FXuint hsize2=getWidth()/4;
 	
 	glbBindingsList->appendHeader(_("Action Name"),NULL,hsize1);
 	glbBindingsList->appendHeader(_("Registry Key"),NULL,hsize2);
@@ -317,8 +317,8 @@ int KeybindingsBox::compareSection(const char *p,const char* q,int s)
     for (x=s; x && *q; x-=(*q++=='\t'));
     do
     {
-        c1=(unsigned char)(*p++);
-        c2=(unsigned char)(*q++);
+        c1=(FXuchar)(*p++);
+        c2=(FXuchar)(*q++);
     }
     while ('\t'<c1 && (c1==c2));
     return c1-c2;
@@ -608,7 +608,7 @@ long KeybindingsBox::onCmdXfwSortByKeyBinding(FXObject*,FXSelector,void*)
 // Clicked on a global list header button
 long KeybindingsBox::onCmdGlbHeaderClicked(FXObject*,FXSelector,void* ptr)
 {	
-	unsigned int num=(unsigned int)(FXuval)ptr;
+	FXuint num=(FXuint)(FXuval)ptr;
 		
 	if (num >= 0 && num <3)
 	{
@@ -627,7 +627,7 @@ long KeybindingsBox::onCmdGlbHeaderClicked(FXObject*,FXSelector,void* ptr)
 // Clicked on a Xfe list header button
 long KeybindingsBox::onCmdXfeHeaderClicked(FXObject*,FXSelector,void* ptr)
 {	
-	unsigned int num=(unsigned int)(FXuval)ptr;
+	FXuint num=(FXuint)(FXuval)ptr;
 		
 	if (num >= 0 && num <3)
 	{
@@ -645,7 +645,7 @@ long KeybindingsBox::onCmdXfeHeaderClicked(FXObject*,FXSelector,void* ptr)
 // Clicked on a Xfi list header button
 long KeybindingsBox::onCmdXfiHeaderClicked(FXObject*,FXSelector,void* ptr)
 {
-	unsigned int num=(unsigned int)(FXuval)ptr;
+	FXuint num=(FXuint)(FXuval)ptr;
 	if (num >= 0 && num <3)
 	{
 		if (num==0)
@@ -662,7 +662,7 @@ long KeybindingsBox::onCmdXfiHeaderClicked(FXObject*,FXSelector,void* ptr)
 // Clicked on a Xfw list header button
 long KeybindingsBox::onCmdXfwHeaderClicked(FXObject*,FXSelector,void* ptr)
 {
-	unsigned int num=(unsigned int)(FXuval)ptr;
+	FXuint num=(FXuint)(FXuval)ptr;
 	if (num >= 0 && num <3)
 	{
 		if (num==0)
@@ -1210,7 +1210,7 @@ long KeybindingsBox::onCmdDefineXfwKeybindings(FXObject*,FXSelector,void*)
 
 
 // Execute dialog box modally
-unsigned int KeybindingsBox::execute(unsigned int placement)
+FXuint KeybindingsBox::execute(FXuint placement)
 {
 	// Save binding dicts for cancel purpose
  	FXString data, regkey;
@@ -1240,7 +1240,7 @@ unsigned int KeybindingsBox::execute(unsigned int placement)
 	}
  
 	// Execute dialog 
-	unsigned int ret=DialogBox::execute(placement);
+	FXuint ret=DialogBox::execute(placement);
     return ret;
 }
 
