@@ -53,7 +53,7 @@ public:
     KeybindingsBox(FXWindow*,FXStringDict*,FXStringDict*,FXStringDict*,FXStringDict*);
     virtual void create();
     virtual ~KeybindingsBox();
-	unsigned int execute(unsigned int);
+	FXuint execute(FXuint);
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdCancel(FXObject*,FXSelector,void*);
 	long onCmdDefineGlbKeybindings(FXObject*,FXSelector,void*);
