@@ -37,7 +37,7 @@ FXIMPLEMENT(MessageBox,DialogBox,MessageBoxMap,ARRAYNUMBER(MessageBoxMap))
 
 
 // Construct message box with given caption, icon, and message text
-MessageBox::MessageBox(FXWindow* owner,const FXString& caption,const FXString& text,FXIcon* ic,unsigned int opts,unsigned int textopts,int x,int y):
+MessageBox::MessageBox(FXWindow* owner,const FXString& caption,const FXString& text,FXIcon* ic,FXuint opts,FXuint textopts,int x,int y):
         DialogBox(owner,caption,opts|DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE,x,y,0,0, 0,0,0,0, 4,4)
 {
     initialize(text,ic,opts&BOX_BUTTON_MASK,textopts);
@@ -45,7 +45,7 @@ MessageBox::MessageBox(FXWindow* owner,const FXString& caption,const FXString& t
 
 
 // Construct free floating message box with given caption, icon, and message text
-MessageBox::MessageBox(FXApp* a,const FXString& caption,const FXString& text,FXIcon* ic,unsigned int opts,unsigned int textopts,int x,int y):
+MessageBox::MessageBox(FXApp* a,const FXString& caption,const FXString& text,FXIcon* ic,FXuint opts,FXuint textopts,int x,int y):
         DialogBox(a,caption,opts|DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE,x,y,0,0, 0,0,0,0, 4,4)
 {
     initialize(text,ic,opts&BOX_BUTTON_MASK,textopts);
@@ -53,7 +53,7 @@ MessageBox::MessageBox(FXApp* a,const FXString& caption,const FXString& text,FXI
 
 
 // Build contents
-void MessageBox::initialize(const FXString& text,FXIcon* ic, unsigned int whichbuttons, unsigned int textoptions)
+void MessageBox::initialize(const FXString& text,FXIcon* ic, FXuint whichbuttons, FXuint textoptions)
 {
     FXButton *initial;
     FXVerticalFrame* content=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -197,7 +197,7 @@ long MessageBox::onCmdCancel(FXObject* sender,FXSelector,void* ptr)
 }
 
 // Show a modal error message
-unsigned int MessageBox::error(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::error(FXWindow* owner,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -208,7 +208,7 @@ unsigned int MessageBox::error(FXWindow* owner,unsigned int opts,const char* cap
 
 
 // Show a modal error message, in free floating window
-unsigned int MessageBox::error(FXApp* app,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::error(FXApp* app,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -219,7 +219,7 @@ unsigned int MessageBox::error(FXApp* app,unsigned int opts,const char* caption,
 
 
 // Show a modal warning message
-unsigned int MessageBox::warning(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::warning(FXWindow* owner,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -230,7 +230,7 @@ unsigned int MessageBox::warning(FXWindow* owner,unsigned int opts,const char* c
 
 
 // Show a modal warning message, in free floating window
-unsigned int MessageBox::warning(FXApp* app,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::warning(FXApp* app,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -241,7 +241,7 @@ unsigned int MessageBox::warning(FXApp* app,unsigned int opts,const char* captio
 
 
 // Show a modal question dialog
-unsigned int MessageBox::question(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::question(FXWindow* owner,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -252,7 +252,7 @@ unsigned int MessageBox::question(FXWindow* owner,unsigned int opts,const char*
 
 
 // Show a modal question dialog, in free floating window
-unsigned int MessageBox::question(FXApp* app,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::question(FXApp* app,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -263,7 +263,7 @@ unsigned int MessageBox::question(FXApp* app,unsigned int opts,const char* capti
 
 
 // Show a modal information dialog
-unsigned int MessageBox::information(FXWindow* owner,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::information(FXWindow* owner,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
@@ -274,7 +274,7 @@ unsigned int MessageBox::information(FXWindow* owner,unsigned int opts,const cha
 
 
 // Show a modal information dialog, in free floating window
-unsigned int MessageBox::information(FXApp* app,unsigned int opts,const char* caption,const char* message,...)
+FXuint MessageBox::information(FXApp* app,FXuint opts,const char* caption,const char* message,...)
 {
     va_list arguments;
     va_start(arguments,message);
