@@ -36,7 +36,7 @@ public:
         ID_LAST
     };
 public:
-    OverwriteBox(FXWindow *win,const FXString& name,const FXString& text,unsigned int opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
+    OverwriteBox(FXWindow *win,const FXString& name,const FXString& text,FXuint opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
 };
 
 #endif
