@@ -24,7 +24,7 @@ FXIMPLEMENT(PathLinker, FXHorizontalFrame, PathLinkerMap, ARRAYNUMBER(PathLinker
 
 
 // Construct object
-PathLinker::PathLinker(FXComposite* a, FileList* flist, DirList* dlist, unsigned int opts): FXHorizontalFrame(a, opts, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2)
+PathLinker::PathLinker(FXComposite* a, FileList* flist, DirList* dlist, FXuint opts): FXHorizontalFrame(a, opts, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2)
 {
 	filelist=flist;
 	dirlist=dlist;
@@ -96,7 +96,7 @@ void PathLinker::setPath(FXString text)
 		visited = visitedPath.find(path+PATHSEPSTRING);
 
 	// If actual path is included in the visited path
-	unsigned int index = 0;
+	FXuint index = 0;
 	if (visited >= 0)
 	{		
 		nextPos = path.find(PATHSEPSTRING, 0);		
@@ -139,7 +139,7 @@ void PathLinker::setPath(FXString text)
     }
     */
     
-    unsigned int ind = 0;
+    FXuint ind = 0;
     nextPos = displayText.find(PATHSEPSTRING, 0);
     previousPos = 0;
         
@@ -177,7 +177,7 @@ void PathLinker::setPath(FXString text)
 
 
 // Update current path according to the clicked button
-void PathLinker::updatePath(FXString text, unsigned int index)
+void PathLinker::updatePath(FXString text, FXuint index)
 {	
 	// Remove trailing /
 	FXString path=::cleanPath(text);
@@ -213,7 +213,7 @@ void PathLinker::updatePath(FXString text, unsigned int index)
     
 	int nextPos = 0;
     int previousPos = 0;
-    unsigned int ind = 0;
+    FXuint ind = 0;
     nextPos = displayText.find(PATHSEPSTRING, 0);
         
     while(nextPos >= 0)
@@ -239,7 +239,7 @@ void PathLinker::updatePath(FXString text, unsigned int index)
 }
 
 
-void PathLinker::setText(unsigned int index, FXString displayText)
+void PathLinker::setText(FXuint index, FXString displayText)
 {	
     if(index < MAX_LINKS)
     {        
@@ -311,7 +311,7 @@ long PathLinker::onUpdPath(FXObject * obj ,FXSelector sel ,void* ptr)
 
 		// Test each link for existence and update to the current path if necessary
 		FXString path=visitedPath;
-		unsigned int n=1;
+		FXuint n=1;
 		while (path != "")
 		{
 			if (!::exists(path))
