@@ -21,7 +21,7 @@ public:
         ID_LAST
     };
 
-    PathLinker(FXComposite* a, FileList* flist, DirList* dlist=NULL, unsigned int opts=0);
+    PathLinker(FXComposite* a, FileList* flist, DirList* dlist=NULL, FXuint opts=0);
 	PathLinker()
 	{}
     virtual void create();
@@ -35,8 +35,8 @@ public:
 protected:
     typedef std::vector<FXButton*> vector_FXButton;
     vector_FXButton linkButtons;
-    unsigned int nbActiveButtons;
-    unsigned int currentButton;
+    FXuint nbActiveButtons;
+    FXuint currentButton;
     FXString visitedPath;
 	TextLabel* focusButton;
 	FXFont* normalFont;
@@ -44,8 +44,8 @@ protected:
 	FileList* filelist;
 	DirList* dirlist;
 private:
-    void updatePath(FXString, unsigned int);
-    void setText(unsigned int, FXString);
+    void updatePath(FXString, FXuint);
+    void setText(FXuint, FXString);
 };
 
 #endif
