@@ -45,15 +45,15 @@ extern FXbool save_win_pos;
 // Create hilite color from given color for gradient controls
 FXColor makeHiliteColorGradient(FXColor color)
 {
-	unsigned int r, g, b;
+	FXuint r, g, b;
 	
 	r=FXREDVAL(color);
 	g=FXGREENVAL(color);
 	b=FXBLUEVAL(color);
 
-	r=(unsigned int)(FXMIN(1.2*r,255));
-	g=(unsigned int)(FXMIN(1.2*g,255));
-	b=(unsigned int)(FXMIN(1.2*b,255));
+	r=(FXuint)(FXMIN(1.2*r,255));
+	g=(FXuint)(FXMIN(1.2*g,255));
+	b=(FXuint)(FXMIN(1.2*b,255));
 
 	return FXRGB(r,g,b);
 }
@@ -62,15 +62,15 @@ FXColor makeHiliteColorGradient(FXColor color)
 // Create shadow color from given color for gradient controls
 FXColor makeShadowColorGradient(FXColor color)
 {
-	unsigned int r, g, b;
+	FXuint r, g, b;
 	
 	r=FXREDVAL(color);
 	g=FXGREENVAL(color);
 	b=FXBLUEVAL(color);
 
-	r=(unsigned int)(0.7*r);
-	g=(unsigned int)(0.7*g);
-	b=(unsigned int)(0.7*b);
+	r=(FXuint)(0.7*r);
+	g=(FXuint)(0.7*g);
+	b=(FXuint)(0.7*b);
 
 	return FXRGB(r,g,b);
 }
@@ -187,7 +187,6 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     oldtimeformat=getApp()->reg().readStringEntry("SETTINGS","time_format",DEFAULT_TIME_FORMAT);
     timeformat->setText(oldtimeformat);
 
-
 	group=new FXGroupBox(options,_("Mouse"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     scroll=new FXCheckButton(group,_("Smooth scrolling in file lists and text windows"));
     matrix = new FXMatrix(group,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_Y);
@@ -286,6 +285,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
     exec=new FXCheckButton(group,_("Confirm execute text files"));
 
 	group=new FXGroupBox(dialogs,_("Warnings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    folder_warning=new FXCheckButton (group,_("Warn when setting current folder in search window"));
 #if defined(linux)
     mount=new FXCheckButton (group,_("Warn when mount points are not responding"));
 	show_mount=new FXCheckButton(group, _("Display mount/umount success messages"));
@@ -315,6 +315,9 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 	show_mount->setCheck(mount_messages);
 #endif
 
+	FXbool folder_warn=getApp()->reg().readUnsignedEntry("OPTIONS","folderwarn",TRUE);
+    folder_warning->setCheck(folder_warn);
+
 	FXbool preserve_date_warn=getApp()->reg().readUnsignedEntry("OPTIONS","preserve_date_warn",TRUE);
     preserve_date_warning->setCheck(preserve_date_warn);
 
@@ -397,7 +400,7 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
     FXGroupBox *colors=new FXGroupBox(visual,_("Custom colors"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
 	FXMatrix *matrix3 = new FXMatrix(colors,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    colorsBox = new FXComboBox(matrix3,NUM_COLORS,NULL,0,COMBOBOX_STATIC|FRAME_SUNKEN|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y);
+    colorsBox = new FXComboBox(matrix3,NUM_COLORS,NULL,0,COMBOBOX_STATIC|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y);
   	colorsBox->setNumVisible(NUM_COLORS);
   	cwell=new FXColorWell(matrix3,FXRGB(0,0,0),this,ID_COLOR,LAYOUT_FILL_X|LAYOUT_FILL_COLUMN|LAYOUT_FILL_Y,0,0,0,0, 10,10,0,0);
   	cwell->setTipText(_("Double click to customize the color"));
@@ -625,7 +628,7 @@ long PreferencesBox::onCmdChangeKeyBindings(FXObject*,FXSelector,void*)
 	str=_("Go to home folder")+TAB+key;
 	glbBindingsDict->insert("go_home",str.text());
 
-	key=getApp()->reg().readStringEntry("KEYBINDINGS","new_file","ctrl-N");
+	key=getApp()->reg().readStringEntry("KEYBINDINGS","new_file","Ctrl-N");
 	str=_("Create new file")+TAB+key;
 	glbBindingsDict->insert("new_file",str.text());
 
@@ -1221,9 +1224,11 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 				view=strtmp.section(',',1);
 				edit=strtmp.section(',',2);
 				
-				// Replace only the view string, if needed
-				if (view==oldimgviewer)
-					view=newimgviewer;
+				// Replace the open and view string, if needed
+				if (open==oldimgviewer)
+					open=newimgviewer;
+ 				if (view==oldimgviewer)
+ 					view=newimgviewer;
 				
 				// Replace with the new value
 				value=open + "," + view + "," + edit + ";" + command;
@@ -1429,6 +1434,7 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_overwrite",overwrite->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_execute",exec->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_drag_and_drop",dnd->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","folder_warn",folder_warning->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","preserve_date_warn",preserve_date_warning->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warning->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_mode",rootmode->getCheck());
@@ -1491,14 +1497,14 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		file_tooltips=TRUE;
 	else
 		file_tooltips=FALSE;
-	getApp()->reg().writeUnsignedEntry("SETTINGS","file_tooltips",(unsigned int)file_tooltips);
+	getApp()->reg().writeUnsignedEntry("SETTINGS","file_tooltips",(FXuint)file_tooltips);
 
 	// Update the relative resize flag
 	if (relativeresize->getCheck())
 		relative_resize=TRUE;
 	else
 		relative_resize=FALSE;
-	getApp()->reg().writeUnsignedEntry("SETTINGS","relative_resize",(unsigned int)relative_resize);
+	getApp()->reg().writeUnsignedEntry("SETTINGS","relative_resize",(FXuint)relative_resize);
 
 	// Update the display path linker flag
 	show_pathlink=showpathlink->getCheck();
@@ -1634,6 +1640,7 @@ long PreferencesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 	mount->setCheck(mount_prev);
 	show_mount->setCheck(show_mount_prev);
 #endif
+	folder_warning->setCheck(folder_warning_prev);
 	preserve_date_warning->setCheck(preserve_date_warning_prev);
 	root_warning->setCheck(root_warning_prev);
 	
@@ -1668,7 +1675,7 @@ long PreferencesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
 
 
 // Execute dialog box modally
-unsigned int PreferencesBox::execute(unsigned int placement)
+FXuint PreferencesBox::execute(FXuint placement)
 {
 	// Save current preferences to restore them if cancel is pressed
 	
@@ -1702,6 +1709,7 @@ unsigned int PreferencesBox::execute(unsigned int placement)
 	mount_prev=mount->getCheck();
 	show_mount_prev=show_mount->getCheck();
 #endif
+	folder_warning_prev=folder_warning->getCheck();
 	preserve_date_warning_prev=preserve_date_warning->getCheck();
 	root_warning_prev=root_warning->getCheck();
 
@@ -1849,7 +1857,7 @@ long PreferencesBox::onUpdControls(FXObject* sender,FXSelector sel,void*)
 // Set scroll wheel lines (Mathew Robertson <mathew@optushome.com.au>)
 long PreferencesBox::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
 {
-    unsigned int value;
+    FXuint value;
     sender->handle(this,FXSEL(SEL_COMMAND,ID_GETINTVALUE),(void*)&value);
     getApp()->setWheelLines(value);
 	getApp()->reg().write();
@@ -1860,7 +1868,7 @@ long PreferencesBox::onCmdWheelAdjust(FXObject* sender,FXSelector,void*)
 // Update the wheel lines button
 long PreferencesBox::onUpdWheelAdjust(FXObject* sender,FXSelector,void*)
 {
-    unsigned int value=getApp()->getWheelLines();
+    FXuint value=getApp()->getWheelLines();
 	sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&value);
     return 1;
 }
