@@ -99,6 +99,7 @@ private:
     FXCheckButton  *exec;
     FXCheckButton  *ask;
     FXCheckButton  *bg;
+    FXCheckButton  *folder_warning;
     FXCheckButton  *preserve_date_warning;
     FXCheckButton  *root_warning;
     FXCheckButton  *mount;
@@ -124,7 +125,7 @@ private:
 	FXbool         relativeresize_prev;
 	FXbool         show_pathlink;
 	FXbool         show_pathlink_prev;
-	unsigned int	       value_prev;
+	FXuint	       value_prev;
 	FXbool		   ask_prev;
 	FXbool		   dnd_prev;
 	FXbool		   trashmv_prev;
@@ -143,8 +144,9 @@ private:
 	FXbool		   show_mount_prev;
 #endif
 	FXbool		   root_warning_prev;
+	FXbool		   folder_warning_prev;
 	FXbool		   preserve_date_warning_prev;
-	unsigned int		   themelist_prev;
+	FXuint		   themelist_prev;
 	FXbool		   smoothscroll_prev;
 	KeybindingsBox 		*bindingsbox;
 	FXStringDict		*glbBindingsDict;
@@ -203,7 +205,7 @@ public:
 	long onCmdWheelAdjust(FXObject*,FXSelector,void*);
 	long onUpdWheelAdjust(FXObject*,FXSelector,void*);
 	long onUpdSingleClickFileopen(FXObject*,FXSelector,void*);
-	unsigned int execute(unsigned int);
+	FXuint execute(FXuint);
 	long onCmdCancel(FXObject*,FXSelector,void*);
 	long onCmdControls(FXObject*,FXSelector ,void*);
 	long onUpdControls(FXObject*,FXSelector,void*);
