@@ -152,14 +152,14 @@ FXIMPLEMENT(PropertiesBox,DialogBox,PropertiesBoxMap,ARRAYNUMBER(PropertiesBoxMa
 // Construct window for one file
 PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
-	unsigned long long filesize;
+	FXulong filesize;
     FXString mod,changed,accessed;
 	FXString grpid, usrid;	
 	FXLabel *sizelabel=NULL;
     struct stat linfo;
     FXString type="", extension, fileassoc;
     FXbool isLink, isBrokenLink;
-    FXString filepath, referredpath;
+    FXString pathname, referredpath;
     char mnttype[64], used[64], avail[64], pctr[64], size[64];
     char buf[MAXPATHLEN+1];
 	FXString hsize;
@@ -266,19 +266,23 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     input = new FXTextField(generalframe,20,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
 
     // Complete file path name
-	filepath=path+PATHSEPSTRING+file;
+	pathname=path+PATHSEPSTRING+file;
 	parentdir=path;
 	filename=file;
 	
+	// Unused in this case
+	files = NULL;
+	paths = NULL;
+	
 	// Initialize mount point flag
 	isMountpoint=FALSE;
 
 	// Warn if non UTF-8 file name
-	if (!isUtf8(filepath.text(),filepath.length()))
+	if (!isUtf8(pathname.text(),pathname.length()))
 		new FXLabel(generalframe,_("=> Warning: file name is not UTF-8 encoded!"),NULL,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW);
 
 	// Get file/link stat info
-    if(lstatrep(filepath.text(),&linfo)!=0)
+    if(lstatrep(pathname.text(),&linfo)!=0)
         return ;
 
 	// Obtain user name
@@ -299,11 +303,11 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	{
 		// Broken link
 		struct stat info;
-		if (statrep(filepath.text(),&info)!=0)
+		if (statrep(pathname.text(),&info)!=0)
 			isBrokenLink=TRUE;
 
 		// Get the path name of the linked file
-		referredpath=::readLink(filepath);
+		referredpath=::readLink(pathname);
 	}
 
     orig_mode=linfo.st_mode;
@@ -324,7 +328,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
     accessed=FXSystem::time(timeformat.text(),linfo.st_atime);;
 
     // Size of the file / link
-    filesize=(unsigned long long)linfo.st_size;
+    filesize=(FXulong)linfo.st_size;
 
     // Is it a directory?
 	isDirectory=S_ISDIR(linfo.st_mode);
@@ -358,7 +362,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		if(isMountpoint)
 		{
 			// Caution : use the -P option to be POSIX compatible!
-			snprintf(buf,sizeof(buf)-1,"df -P -B 1 '%s'",filepath.text());
+			snprintf(buf,sizeof(buf)-1,"df -P -B 1 '%s'",pathname.text());
 			p=popen(buf,"r");
 			FXbool success=TRUE;
 			if (fgets(buf,sizeof(buf),p) == NULL)
@@ -405,7 +409,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	else
     {
 		// Try to use association table	
-		extension=FXPath::name(filepath).rafter('.',1);
+		extension=FXPath::name(pathname).rafter('.',1);
 		extension=extension.lower();
 		if (extension!="")
 			fileassoc=getApp()->reg().readStringEntry("FILETYPES",extension.text(),"");
@@ -670,9 +674,17 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	// Regular file
     else
     {
+#if __WORDSIZE == 64
+        snprintf(size,sizeof(size)-1,"%lu",filesize);
+#else
         snprintf(size,sizeof(size)-1,"%llu",filesize);
+#endif
         hsize=::hSize(size);
+#if __WORDSIZE == 64
+        snprintf(size,sizeof(size)-1,_("%s (%lu bytes)"),hsize.text(),filesize);        
+#else
         snprintf(size,sizeof(size)-1,_("%s (%llu bytes)"),hsize.text(),filesize);        
+#endif
 		sizelabel->setText(_("Size:"));
 		fileSize->setText(size);
         fileModified->setText(mod);
@@ -688,14 +700,14 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		subpath.erase(0,trashfileslocation.length()+1);
 		FXString trashbasename=subpath.before('/');
 		if (trashbasename=="")
-			trashbasename=FXPath::name(filepath);
+			trashbasename=FXPath::name(pathname);
 		subpath.erase(0,trashbasename.length());
 		
 		// Read the .trashinfo file
 		FILE *fp;
 		char line[1024];
 		FXString origpath="", delstr="";
-		long deldate=0;
+		FXlong deldate=0;
 		FXbool success=TRUE;
 		FXString trashinfopathname=trashinfolocation+PATHSEPSTRING+trashbasename+".trashinfo";
 		if ((fp=fopen(trashinfopathname.text(),"r"))!=NULL)
@@ -726,7 +738,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		if (subpath=="")
 			origpath=origpath+subpath;
 		else
-			origpath=origpath+subpath+FXPath::name(filepath);
+			origpath=origpath+subpath+FXPath::name(pathname);
 		
 		// Convert date
 		deldate=deltime(delstr);
@@ -762,7 +774,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 
 
 // Construct window for multiple files
-PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path): DialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
+PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString *path): DialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE)
 {
 	struct stat linfo;
 	FXString grpid, usrid;
@@ -802,8 +814,6 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 	filesSize=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
 	new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
 	filesSizeDetails=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
-	new FXLabel(attrmatrix,_("Location:"),NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
-	location=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
 
     // Second item is Access Permissions
     new FXTabItem(tabbook,_("&Permissions"),NULL);
@@ -811,7 +821,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 
     // Get file/link info of the first file of the list
 	// This is used as a guess for the username, group and permissions of the whole list
-	FXString pathname=path+PATHSEPSTRING+file[0];
+	FXString pathname=path[0]+PATHSEPSTRING+file[0];
     if(lstatrep(pathname.text(),&linfo)!=0)
         return ;
 	
@@ -849,17 +859,14 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
     perm->cmd = PropertiesBox::ID_SET;
 	perm->flt = PropertiesBox::ID_ALL;
     files = file;
+    paths = path;
     source = "";
     num = n;
 
-	// Parent directory
-	parentdir=path;
-	location->setText(parentdir);
-
 	// Total size and files type
 	for(i=0;i<num;i++)
 	{
-		FXString pathname=parentdir+PATHSEPSTRING+files[i];
+		FXString pathname=paths[i]+PATHSEPSTRING+files[i];
 		if(lstatrep(pathname.text(),&linfo)!=0)
 			continue ;
 
@@ -933,6 +940,9 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 }
 
 
+
+
+
 // Make window
 void PropertiesBox::create()
 {
@@ -1284,7 +1294,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 	for (i=0; i<num; i++)
 	{
 		struct stat linfo;
-		FXString pathname=parentdir+PATHSEPSTRING+files[i];
+		FXString pathname=FXPath::absolute(paths[i],files[i]);
 		if(lstatrep(pathname.text(),&linfo)!=0)
 			continue ;
 
@@ -1352,7 +1362,8 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
         {
             struct stat linfo;
             mode_t m;
-			FXString pathname=parentdir+PATHSEPSTRING+files[i];
+			
+			FXString pathname=FXPath::absolute(paths[i],files[i]);
             if(lstatrep(pathname.text(),&linfo)!=0)
                 continue ;
 
@@ -1407,7 +1418,6 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 		getApp()->endWaitCursor();
     }
 
-
 	// Redraw the file lists
 	((XFileExplorer*) mainWindow)->redrawPanels();
 
@@ -1575,15 +1585,23 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 			// Directory but not mount point
 			if (isDirectory && !isMountpoint)
 			{
-				unsigned long long dirsize;
-				unsigned int nbfiles=0, nbsubfolders=0;
+				FXulong dirsize;
+				FXuint nbfiles=0, nbsubfolders=0;
 
 				FXString dirpath=FXPath::absolute(parentdir,filename);
 				strlcpy(buf,dirpath.text(),dirpath.length()+1);
 				dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
+#if __WORDSIZE == 64
+				snprintf(size,sizeof(size)-1,"%lu",dirsize);				
+#else
 				snprintf(size,sizeof(size)-1,"%llu",dirsize);				
+#endif
 				hsize=::hSize(size);
+#if __WORDSIZE == 64
+				snprintf(size,sizeof(size)-1,_("%s (%lu bytes)"),hsize.text(),dirsize);        
+#else
 				snprintf(size,sizeof(size)-1,_("%s (%llu bytes)"),hsize.text(),dirsize);        
+#endif
 				fileSize->setText(size);
 				snprintf(size,sizeof(size)-1,_("%u files, %u subfolders"),nbfiles-nbsubfolders,nbsubfolders-1);        
 				filesSizeDetails->setText(size);
@@ -1593,32 +1611,37 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 		// Multiple files
 		else
 		{
-			unsigned long long filesize, dirsize, totalsize=0;
-			unsigned int totalnbfiles=0, totalnbsubfolders=0;
+			FXulong filesize, dirsize, totalsize=0;
+			FXuint totalnbfiles=0, totalnbsubfolders=0;
 			struct stat info;
-			//int dotdot=0;
 
 			// Total size and files type
 			for (int i=0;i<num;i++)
 			{
-				if(lstatrep(files[i].text(),&info)!=0)
+				FXString pathname;
+				
+				if (paths == NULL)
+					pathname=FXPath::absolute(parentdir,files[i]);
+				else
+					pathname=FXPath::absolute(paths[i],files[i]);
+								
+				if(lstatrep(pathname.text(),&info)!=0)
+				{
 					continue ;
+				}
 
 				// Special case of the ".." directory
 				if (files[i]=="..")
 				{	
-					//dotdot=1;
 					continue;
 				}
 
 				// Is it a directory?
 				isDirectory=S_ISDIR(info.st_mode);
 				if(isDirectory)
-				{
-					// Recursive size
-					FXString dirpath=FXPath::absolute(parentdir,files[i]);
-					strlcpy(buf,dirpath.text(),dirpath.length()+1);
-					unsigned int nbfiles=0, nbsubfolders=0;
+				{						
+					strlcpy(buf,pathname.text(),pathname.length()+1);
+					FXuint nbfiles=0, nbsubfolders=0;
 					dirsize=pathsize(buf,&nbfiles,&nbsubfolders);
 					totalsize+=dirsize;
 					totalnbfiles+=(nbfiles-nbsubfolders);
@@ -1634,9 +1657,17 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o,FXSelector s,void* p)
 			}
 				
 			// Display total size
+#if __WORDSIZE == 64
+			snprintf(size,sizeof(size)-1,"%lu",totalsize);
+#else
 			snprintf(size,sizeof(size)-1,"%llu",totalsize);
+#endif
 			hsize=::hSize(size);
+#if __WORDSIZE == 64
+			snprintf(size,sizeof(size)-1,_("%s (%lu bytes)"),hsize.text(),totalsize);        
+#else
 			snprintf(size,sizeof(size)-1,_("%s (%llu bytes)"),hsize.text(),totalsize);        
+#endif
 			filesSize->setText(size);
 			snprintf(size,sizeof(size)-1,_("%u files, %u subfolders"),totalnbfiles,totalnbsubfolders);        
 			filesSizeDetails->setText(size);
