@@ -58,6 +58,7 @@ private:
 	FXLabel*	deletiondate;
     FXLabel*	ext;
     FXString*	files;
+    FXString*	paths;
 	FXLabel*	name_encoding;
     FXString 	source;
 	FXString	parentdir;
@@ -138,7 +139,7 @@ public:
 public:
     virtual void create();
     PropertiesBox(FXWindow *win,FXString file,FXString path);
-    PropertiesBox(FXWindow *win,FXString *files,int num,FXString path);
+    PropertiesBox(FXWindow *win,FXString *file,int num,FXString *path);
     long onCmdAcceptSingle(FXObject*,FXSelector,void*);
     long onCmdAcceptMult(FXObject*,FXSelector,void*);
     long onCmdCancel(FXObject*,FXSelector,void*);
