@@ -126,10 +126,10 @@ void StringList::removeAfterItem(StringItem *item)
 
 
 // Number of items in the list
-FXint StringList::getNumItems(void)
+int StringList::getNumItems(void)
 {
     StringItem* item;
-	FXint num=0;
+	int num=0;
 	
     item=this->first;
     
@@ -223,9 +223,9 @@ void StringList::removeAllItems(void)
 
 
 // Get item based on its position (first position is 0)
-StringItem* StringList::getItemAtPos(const FXint pos)
+StringItem* StringList::getItemAtPos(const int pos)
 {
-    FXint num=getNumItems();
+    int num=getNumItems();
 	if (num==0 || pos<0 || pos>num-1)
 		return NULL;
 	
