@@ -65,11 +65,11 @@ public:
     void removeBeforeItem(StringItem*);
     void removeAfterItem(StringItem*);
     void removeItem(StringItem*);
-	FXint getNumItems(void);
+	int getNumItems(void);
 	void removeAllItemsBefore(StringItem*);
 	void removeAllItemsAfter(StringItem*);
 	void removeAllItems(void); 
-	StringItem* getItemAtPos(const FXint);
+	StringItem* getItemAtPos(const int);
 	void printFromFirst();
     void printFromLast();
 };
