@@ -60,7 +60,7 @@ const char TextLabel::textDelimiters[]="~.,/\\`'!@#$%^&*()-=+{}|[]\":;<>?";
 
 
 // Construct and init
-TextLabel::TextLabel(FXComposite* p,int ncols,FXObject* tgt,FXSelector sel,unsigned int opts,int x,int y,int w,int h,int pl,int pr,int pt,int pb):
+TextLabel::TextLabel(FXComposite* p,int ncols,FXObject* tgt,FXSelector sel,FXuint opts,int x,int y,int w,int h,int pl,int pr,int pt,int pb):
         FXFrame(p,opts,x,y,w,h,pl,pr,pt,pb)
 {
     if (ncols<0)
@@ -199,8 +199,8 @@ long TextLabel::onSelectionRequest(FXObject* sender,FXSelector sel,void* ptr)
 {
     FXEvent *event=(FXEvent*)ptr;
     FXString string;
-    unsigned int   start;
-    unsigned int   len;
+    FXuint   start;
+    FXuint   len;
 
     // Make sure
     FXASSERT(0<=anchor && anchor<=contents.length());
@@ -1284,7 +1284,7 @@ long TextLabel::onKeyPress(FXObject*,FXSelector,void* ptr)
             return 1;
         default:
 ins:
-            if ((event->state&(CONTROLMASK|ALTMASK)) || ((unsigned char)event->text[0]<32))
+            if ((event->state&(CONTROLMASK|ALTMASK)) || ((FXuchar)event->text[0]<32))
             	return 0;
             return 1;
         }
@@ -1328,7 +1328,7 @@ long TextLabel::onKeyRelease(FXObject*,FXSelector,void* ptr)
             if (event->state&CONTROLMASK)
             	return 1;
         default:
-            if ((event->state&(CONTROLMASK|ALTMASK)) || ((unsigned char)event->text[0]<32))
+            if ((event->state&(CONTROLMASK|ALTMASK)) || ((FXuchar)event->text[0]<32))
             	return 0;
             return 1;
         }
@@ -1481,9 +1481,9 @@ void TextLabel::setNumColumns(int ncols)
 
 
 // Set text justify style
-void TextLabel::setJustify(unsigned int style)
+void TextLabel::setJustify(FXuint style)
 {
-    unsigned int opts=(options&~JUSTIFY_MASK) | (style&JUSTIFY_MASK);
+    FXuint opts=(options&~JUSTIFY_MASK) | (style&JUSTIFY_MASK);
     if (options!=opts)
     {
         shift=0;
@@ -1495,7 +1495,7 @@ void TextLabel::setJustify(unsigned int style)
 
 
 // Get text justify style
-unsigned int TextLabel::getJustify() const
+FXuint TextLabel::getJustify() const
 {
     return (options&JUSTIFY_MASK);
 }
