@@ -93,7 +93,7 @@ public:
 public:
 
     // Construct text field wide enough to display ncols columns
-    TextLabel(FXComposite* p,int ncols,FXObject* tgt=NULL,FXSelector sel=0,unsigned int opts=TEXTFIELD_NORMAL,int x=0,int y=0,int w=0,int h=0,int pl=DEFAULT_PAD,int pr=DEFAULT_PAD,int pt=DEFAULT_PAD,int pb=DEFAULT_PAD);
+    TextLabel(FXComposite* p,int ncols,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=TEXTFIELD_NORMAL,int x=0,int y=0,int w=0,int h=0,int pl=DEFAULT_PAD,int pr=DEFAULT_PAD,int pt=DEFAULT_PAD,int pb=DEFAULT_PAD);
 
     // Create server-side resources
     virtual void create();
@@ -213,10 +213,10 @@ public:
     * Note that JUSTIFY_CENTER_X can not be set from the constructor since by
     * default text fields are left-justified.
     */
-    void setJustify(unsigned int mode);
+    void setJustify(FXuint mode);
 
     // Return text justification mode
-    unsigned int getJustify() const;
+    FXuint getJustify() const;
 
     // Change word delimiters
     void setDelimiters(const char* delims=textDelimiters)
