@@ -20,7 +20,7 @@ FXIMPLEMENT(TextWindow,DialogBox,TextWindowMap,ARRAYNUMBER(TextWindowMap))
 
 
 // Construct Text dialog box
-TextWindow::TextWindow(FXWindow *owner, const FXString& name, FXint nblines, FXint nbcols):
+TextWindow::TextWindow(FXWindow *owner, const FXString& name, int nblines, int nbcols):
         DialogBox(owner,name,DECOR_ALL,0,0,0,0, 6,6,6,6, 4,4)
 {
 
@@ -29,7 +29,7 @@ TextWindow::TextWindow(FXWindow *owner, const FXString& name, FXint nblines, FXi
     FXButton *button=new FXButton(closebox,_("&Close"),NULL,this,DialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);
 
     // Text part
-    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
+    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN,0,0,0,0, 0,0,0,0);
     text=new FXText(textbox,NULL,0,TEXT_READONLY|TEXT_WORDWRAP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     text->setVisibleRows(nblines);
     text->setVisibleColumns(nbcols);
@@ -38,7 +38,7 @@ TextWindow::TextWindow(FXWindow *owner, const FXString& name, FXint nblines, FXi
 }
 
 // Construct Text dialog box
-TextWindow::TextWindow(FXApp* app, const FXString& name, FXint nblines, FXint nbcols):
+TextWindow::TextWindow(FXApp* app, const FXString& name, int nblines, int nbcols):
         DialogBox(app,name,DECOR_ALL,0,0,0,0, 6,6,6,6, 4,4)
 {
 
@@ -47,7 +47,7 @@ TextWindow::TextWindow(FXApp* app, const FXString& name, FXint nblines, FXint nb
     FXButton *button=new FXButton(closebox,_("&Close"),NULL,this,DialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);
 
     // Text part
-    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
+    FXHorizontalFrame *textbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN,0,0,0,0, 0,0,0,0);
     text=new FXText(textbox,NULL,0,TEXT_READONLY|TEXT_WORDWRAP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     text->setVisibleRows(nblines);
     text->setVisibleColumns(nbcols);
@@ -56,14 +56,14 @@ TextWindow::TextWindow(FXApp* app, const FXString& name, FXint nblines, FXint nb
 }
 
 // Change the text in the buffer to new text
-void TextWindow::setText(const FXchar* str)
+void TextWindow::setText(const char* str)
 {
 	text->setText(str,strlen(str));
 	getApp()->repaint();
 }
 
 // Append new text at the end of the buffer
-void TextWindow::appendText(const FXchar* str)
+void TextWindow::appendText(const char* str)
 {
 	text->appendText(str,strlen(str));
 	getApp()->repaint();
@@ -84,7 +84,7 @@ void TextWindow::scrollToLastLine(void)
 }
 
 // Get text length
-FXint TextWindow::getLength(void)
+int TextWindow::getLength(void)
 {
 	return (text->getLength());
 }
