@@ -18,14 +18,14 @@ public:
         ID_LAST
     };
 public:
-    TextWindow(FXWindow* owner, const FXString& name, FXint nblines, FXint nbcols);
-    TextWindow(FXApp* app, const FXString& name, FXint nblines, FXint nbcols);
+    TextWindow(FXWindow* owner, const FXString& name, int nblines, int nbcols);
+    TextWindow(FXApp* app, const FXString& name, int nblines, int nbcols);
     virtual ~TextWindow();
-	void setText(const FXchar*);
-	void appendText(const FXchar*);
+	void setText(const char*);
+	void appendText(const char*);
 	void scrollToLastLine(void);
 	void setFont(FXFont*);
-	FXint getLength(void);
+	int getLength(void);
 };
 
 #endif
