@@ -493,7 +493,7 @@ long ViewWindow::onCmdOpen(FXObject*,FXSelector,void*)
     if(opendialog.execute())
     {
         FXString* files=opendialog.getFilenames();
-		unsigned int i=0;
+		FXuint i=0;
 		while (files[i]!=FXString::null)
 		{
 			ViewWindow *window=findWindow(files[i]);
@@ -615,8 +615,8 @@ void ViewWindow::saveConfig()
     FXString fontspec;
 
 	// Write new window size and position back to registry
-    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(unsigned int)getWidth());
-    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(unsigned int)getHeight());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
 
 	if (save_win_pos)
 	{
