@@ -37,7 +37,7 @@ FXbool save_win_pos;
 FXIMPLEMENT_ABSTRACT(FXTextCommand,FXCommand,NULL,0)
 
 // Return size of record plus any data kept here
-unsigned int FXTextCommand::size() const
+FXuint FXTextCommand::size() const
 {
     return sizeof(FXTextCommand)+ndel;
 }
@@ -207,7 +207,7 @@ Preferences::Preferences(WriteWindow *owner):DialogBox(owner,_("XFileWrite Prefe
 	
 	new FXLabel(matrix,_("Tabulation size:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     tabsize = new FXTextField(matrix,10,NULL,0,TEXTFIELD_INTEGER|JUSTIFY_RIGHT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_X|LAYOUT_FILL_ROW,0,0,0,0, 2,2,1,1);
-    int tabcols=getApp()->reg().readIntEntry("OPTIONS","tabcols",80);
+    int tabcols=getApp()->reg().readIntEntry("OPTIONS","tabcols",8);
 	tabsize->setText(FXStringVal(tabcols));
 
     new FXLabel(matrix,_("Strip carriage returns:")+(FXString)"                ",NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
@@ -304,7 +304,7 @@ long Preferences::onCmdCancel(FXObject* o,FXSelector s,void* p)
 
 
 // Execute dialog box modally
-unsigned int Preferences::execute(unsigned int placement)
+FXuint Preferences::execute(FXuint placement)
 {
 	// Save current preferences to restore them if cancel is pressed
 	
@@ -1076,8 +1076,8 @@ FXbool WriteWindow::loadFile(const FXString& file)
     // Lines numbering
     if (linesnum)
     {
-        unsigned int size=editor->getNumRows();
-        unsigned int cols=(unsigned int)ceil(log10(size));
+        FXuint size=editor->getNumRows();
+        FXuint cols=(FXuint)ceil(log10(size));
         editor->setBarColumns(cols);
     }
     else
@@ -1473,7 +1473,7 @@ long WriteWindow::onCmdOpen(FXObject*,FXSelector,void*)
     if(opendialog.execute())
     {
         FXString* files=opendialog.getFilenames();
-        unsigned int i=0;
+        FXuint i=0;
         while (files[i]!=FXString::null)
         {
             WriteWindow *window=findWindow(files[i]);
@@ -1540,8 +1540,8 @@ long WriteWindow::onCmdOpenRecent(FXObject*,FXSelector,void* ptr)
 long WriteWindow::onEditDNDDrop(FXObject*,FXSelector,void*)
 {
     char *data;
-    unsigned int len;
-    if(getDNDData(FROM_DRAGNDROP,urilistType,(unsigned char*&)data,len))
+    FXuint len;
+    if(getDNDData(FROM_DRAGNDROP,urilistType,(FXuchar*&)data,len))
     {
         FXString urilist(data,len);
         FXString file=FXURL::fileFromURL(urilist.before('\r'));
@@ -1572,7 +1572,7 @@ long WriteWindow::onEditDNDMotion(FXObject*,FXSelector,void*)
 // Save changes, prompt for new filename
 FXbool WriteWindow::saveChanges()
 {
-    unsigned int answer;
+    FXuint answer;
     FXString file;
     if(isModified())
     {
@@ -1772,8 +1772,8 @@ long WriteWindow::onCmdLinesNum(FXObject*,FXSelector,void*)
     linesnum=!linesnum;
     if (linesnum)
     {
-        unsigned int size=editor->getNumRows();
-        unsigned int cols=(unsigned int)ceil(log10(size));
+        FXuint size=editor->getNumRows();
+        FXuint cols=(FXuint)ceil(log10(size));
         editor->setBarColumns(cols);
     }
     else
@@ -1806,7 +1806,7 @@ long WriteWindow::onUpdOverstrike(FXObject* sender,FXSelector,void*)
 // Update box for size display
 long WriteWindow::onUpdNumRows(FXObject* sender,FXSelector,void*)
 {
-    unsigned int size=editor->getNumRows();
+    FXuint size=editor->getNumRows();
     sender->handle(this,FXSEL(SEL_COMMAND,ID_SETINTVALUE),(void*)&size);
     return 1;
 }
@@ -1914,9 +1914,9 @@ long WriteWindow::onCmdSearch(FXObject*,FXSelector,void*)
     int beg[10];
     int end[10];
     int pos;
-    unsigned int code;
+    FXuint code;
     FXString searchstring;
-    unsigned int searchflags;
+    FXuint searchflags;
     do
     {
         code=searchdialog->execute();
@@ -1948,7 +1948,7 @@ long WriteWindow::onCmdReplace(FXObject*,FXSelector,void*)
 {
     replacedialog=new FXReplaceDialog(this,_("Replace"),replaceicon);
     int beg[10],end[10],fm,to,len,pos;
-    unsigned int searchflags,code;
+    FXuint searchflags,code;
     FXString searchstring;
     FXString replacestring;
     FXString replacevalue;
@@ -2023,7 +2023,7 @@ ret:
 long WriteWindow::onCmdSearchSel(FXObject*,FXSelector sel,void*)
 {
     FXString string;
-    unsigned int searchflags;
+    FXuint searchflags;
     FXString searchstring;
     int pos=editor->getCursorPos();
     int beg,end;
