@@ -20,7 +20,7 @@ protected:
 public:
     FXTextCommand(FXText* txt,int p,int nd,int ni):text(txt),buffer(NULL),pos(p),ndel(nd),nins(ni)
     {}
-    virtual unsigned int size() const;
+    virtual FXuint size() const;
     virtual ~FXTextCommand()
     {
         FXFREE(&buffer);
@@ -139,7 +139,7 @@ public:
     {
         return (XFileWrite*)DialogBox::getApp();
     }
-	unsigned int execute(unsigned int);
+	FXuint execute(FXuint);
 	long onCmdCancel(FXObject*,FXSelector,void*);
 	long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdTextBackColor(FXObject*,FXSelector,void*);
@@ -196,10 +196,10 @@ protected:
 	FXReplaceDialog     *replacedialog;
 	FXbool				smoothscroll;
 	FXbool 				fromreg;			// Read window size and position from the regsitry
-	unsigned int 				ww;			        // Window width
-	unsigned int 				hh;					// Window height
-	unsigned int 				xx;					// Window x position 
-	unsigned int 				yy;					// Window y position
+	FXuint 				ww;			        // Window width
+	FXuint 				hh;					// Window height
+	FXuint 				xx;					// Window x position 
+	FXuint 				yy;					// Window y position
 protected:
     void loadConfig();
     void saveConfig();
