@@ -23,6 +23,7 @@
 #include "Bookmarks.h"
 #include "Preferences.h"
 #include "TextWindow.h"
+#include "SearchWindow.h"
 
 
 // Helper function
@@ -78,7 +79,7 @@ protected:
 	FXString		trashfileslocation;
 	FXString		trashinfolocation;
 	FXString		startlocation;
-	unsigned int			liststyle;
+	FXuint			liststyle;
 	FXColor			listbackcolor;
 	FXColor			listforecolor;
 	FXColor			highlightcolor;
@@ -91,7 +92,7 @@ protected:
 	PreferencesBox*    prefsdialog;
 	TextWindow*		   helpwindow;
 	FXString 		message;
-	unsigned int 			panelfocus;
+	FXuint 			panelfocus;
 	FXString		startdirectory1;
 	FXString		startdirectory2;
 	FXbool			starticonic;
@@ -103,6 +104,11 @@ protected:
 	double        treetwopanels_lpanel_pct;
 	FXString        prevdir;
 	int			prev_width;
+	FXuint			search_xpos;
+	FXuint			search_ypos;
+	FXuint			search_width;
+	FXuint			search_height;
+	SearchWindow*	searchwindow;
 public:
 	enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -128,6 +134,7 @@ public:
         ID_FILE_TRASH,
         ID_FILE_RESTORE,
         ID_FILE_ASSOC,
+		ID_FILE_SEARCH,
 		ID_CLEAR_LOCATION,
 		ID_GOTO_LOCATION,
         ID_RUN,
@@ -186,6 +193,7 @@ public:
 	long onUpdFileDelete(FXObject*,FXSelector,void*);
 	long onUpdFileTrash(FXObject*,FXSelector,void*);
 	long onUpdFileRestore(FXObject*,FXSelector,void*);
+	long onCmdFileSearch(FXObject*,FXSelector sel,void*);
 	long onCmdDirUp(FXObject*,FXSelector,void*);
 	long onCmdDirBack(FXObject*,FXSelector,void*);
 	long onUpdDirBack(FXObject*,FXSelector,void*);
@@ -223,6 +231,7 @@ public:
 	{
 		lpanel->getCurrent()->setDirectory(pathname,FALSE);
 		lpanel->getCurrent()->updatePath();
+		dirpanel->setDirectory(pathname,TRUE);
 	}
 
 	// Change default cursor for file and dir panels
