@@ -32,12 +32,13 @@
 
 // Add FOX hacks
 #include "foxhacks.cpp"
+#include "clearlooks.cpp"
 
 char **args;
 FXColor listbackcolor, listforecolor;
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
-unsigned int single_click;
+FXuint single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXbool show_pathlink;
@@ -52,7 +53,7 @@ FXString xdgdatahome;
 #define hand_height 32
 #define hand_x_hot 6
 #define hand_y_hot 1
- static const unsigned char hand_bits[] = {
+ static const FXuchar hand_bits[] = {
 	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
 	0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
 	0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
@@ -65,7 +66,7 @@ FXString xdgdatahome;
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
  
- static const unsigned char hand_mask_bits[] = {
+ static const FXuchar hand_mask_bits[] = {
 	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
 	0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
 	0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
@@ -252,7 +253,7 @@ XFileImage::XFileImage(FXApp* a, FXbool smoothscroll):FXMainWindow(a,"Xfi ",NULL
     FXHorizontalFrame* pathframe=new FXHorizontalFrame(filebox,LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0, 0,0);
 
 	// File list
-	unsigned int options;
+	FXuint options;
 	if (smoothscroll)
 		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT;
 	else
@@ -627,7 +628,7 @@ long XFileImage::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
     // Popup menu pane
 	FXMenuPane menu(this);
     int x,y;
-    unsigned int state;
+    FXuint state;
     getRoot()->getCursorPosition(x,y,state);
 
 	new FXMenuCommand(&menu,_("Go ho&me"),homeicon,this,ID_HOME);
@@ -1263,7 +1264,7 @@ long XFileImage::onCmdToggleHidden(FXObject* sender,FXSelector sel,void* ptr)
 // Update toggle hidden command
 long XFileImage::onUpdToggleHidden(FXObject* sender,FXSelector sel,void* ptr)
 {	
-    unsigned int msg = FXWindow::ID_UNCHECK;
+    FXuint msg = FXWindow::ID_UNCHECK;
 	hiddenfiles = filelist->shownHiddenFiles();
 		
 	if(hiddenfiles == TRUE)
@@ -1289,7 +1290,7 @@ long XFileImage::onCmdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr
 // Update toggle hidden command
 long XFileImage::onUpdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr)
 {	
-    unsigned int msg = FXWindow::ID_UNCHECK;
+    FXuint msg = FXWindow::ID_UNCHECK;
 	thumbnails = filelist->shownThumbnails();
 		
 	if(thumbnails == TRUE)
@@ -1358,7 +1359,7 @@ long XFileImage::onUpdFileView(FXObject* sender,FXSelector sel,void* ptr)
 		fileheight_pct=(double)(filebox->getHeight())/(double)(getHeight());
 		
 	// Update radio buttons
-	unsigned int msg = FXWindow::ID_UNCHECK;
+	FXuint msg = FXWindow::ID_UNCHECK;
 		
     switch(FXSELID(sel))
     {
@@ -1439,17 +1440,17 @@ long XFileImage::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
     {
         if(filelist->isItemDirectory(index))
         {
-			FXString filepath=filelist->getItemPathname(index);
+			FXString pathname=filelist->getItemPathname(index);
 
 			// Does not have access
-			if(!::isReadExecutable(filepath))
+			if(!::isReadExecutable(pathname))
 			{
-				MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+				MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), pathname.text());
 				return 0;
 			}
-            filelist->setDirectory(filepath);
-            pathlink->setPath(filepath);
-   			pathtext->setText(filepath);
+            filelist->setDirectory(pathname);
+            pathlink->setPath(pathname);
+   			pathtext->setText(pathname);
         }
         else if(filelist->isItemFile(index))
         {
@@ -1469,7 +1470,7 @@ long XFileImage::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
 	{		
 		// In detailed mode, avoid single click when cursor is not over the first column
 		int x, y;
-		unsigned int state;
+		FXuint state;
 		getCursorPosition(x,y,state);
 		FXbool allow=TRUE;
 		if (!(filelist->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-filelist->getXPosition())>filelist->getHeaderSize(0))
@@ -1480,17 +1481,17 @@ long XFileImage::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
 		{
 			if((single_click != SINGLE_CLICK_NONE) && filelist->isItemDirectory(index) && allow)
 			{
-				FXString filepath=filelist->getItemPathname(index);
+				FXString pathname=filelist->getItemPathname(index);
 
 				// Does not have access
-				if(!::isReadExecutable(filepath))
+				if(!::isReadExecutable(pathname))
 				{
-					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), pathname.text());
 					return 0;
 				}
-				filelist->setDirectory(filepath);
-				pathlink->setPath(filepath);
-   				pathtext->setText(filepath);
+				filelist->setDirectory(pathname);
+				pathlink->setPath(pathname);
+   				pathtext->setText(pathname);
 			}
 			else if((single_click == SINGLE_CLICK_DIR_FILE) && filelist->isItemFile(index) && allow)
 			{
@@ -1736,10 +1737,10 @@ void XFileImage::start(FXString startimage)
 void XFileImage::create()
 {
 	// Get size and position
-    unsigned int ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);    // Workaround for a possible bug in some WMs
-    unsigned int hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);  // Workaround for a possible bug in some WMs
+    FXuint ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);    // Workaround for a possible bug in some WMs
+    FXuint hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);  // Workaround for a possible bug in some WMs
     fileheight_pct=getApp()->reg().readRealEntry("OPTIONS","fileheight_pct",0.25);
-    unsigned int fs=getApp()->reg().readIntEntry("OPTIONS","filesshown",TRUE);
+    FXuint fs=getApp()->reg().readIntEntry("OPTIONS","filesshown",TRUE);
 
 	filelist->setDirectory(FXSystem::getCurrentDirectory());
    	pathlink->setPath(FXSystem::getCurrentDirectory());
@@ -1778,7 +1779,7 @@ void XFileImage::create()
 	//filelist->showThumbnails(thumbnails);
   
 	// Get list style
-	liststyle=getApp()->reg().readUnsignedEntry("OPTIONS","liststyle",(unsigned int)IconList::ID_SHOW_DETAILS);
+	liststyle=getApp()->reg().readUnsignedEntry("OPTIONS","liststyle",(FXuint)IconList::ID_SHOW_DETAILS);
 	filelist->setListStyle(liststyle);
 
 	// Get file view
@@ -1821,8 +1822,8 @@ void XFileImage::create()
 void XFileImage::saveConfig()
 {
     // Write new window size and position back to registry
-	getApp()->reg().writeUnsignedEntry("OPTIONS","width",(unsigned int)getWidth());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","height",(unsigned int)getHeight());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
 
 	if (save_win_pos)
 	{
