@@ -10,8 +10,8 @@ class XFileImage : public FXMainWindow
 protected:
 	FXbool             hiddenfiles;           // Show or hide hidden files
 	FXbool             thumbnails;            // Show or hide image thumbnails
-	unsigned int             fileview;              // File list view
-	unsigned int			   liststyle;             // Icon list style
+	FXuint             fileview;              // File list view
+	FXuint			   liststyle;             // Icon list style
     FXImageView       *imageview;             // Image viewer
     FXRecentFiles      mrufiles;              // Recent files
     FXString           filename;              // File being viewed
