@@ -25,6 +25,7 @@
 
 // Add FOX hacks
 #include "foxhacks.cpp"
+#include "clearlooks.cpp"
 
 
 char **args;
@@ -32,7 +33,7 @@ FXbool dpkg=FALSE;
 FXbool rpm=FALSE;
 FXColor highlightcolor;
 FXbool allowPopupScroll=FALSE;
-unsigned int single_click;
+FXuint single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXbool save_win_pos;
@@ -45,7 +46,7 @@ FXString xdgdatahome;
 #define hand_height 32
 #define hand_x_hot 6
 #define hand_y_hot 1
- static const unsigned char hand_bits[] = {
+ static const FXuchar hand_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
    0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
    0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
@@ -58,7 +59,7 @@ FXString xdgdatahome;
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
  
- static const unsigned char hand_mask_bits[] = {
+ static const FXuchar hand_mask_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
    0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
    0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
@@ -341,8 +342,8 @@ long XFilePackage::onCmdUninstall(FXObject*,FXSelector,void*)
 void XFilePackage::saveConfig()
 {
     // Write new window size and position back to registry
-    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(unsigned int)getWidth());
-    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(unsigned int)getHeight());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
 
 	if (save_win_pos)
 	{
@@ -587,8 +588,8 @@ void XFilePackage::create()
         toolbar->hide();
 
     // Get size
-    unsigned int width=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
-    unsigned int height=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
+    FXuint width=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
+    FXuint height=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
 
 	// Get position and position window
     if (save_win_pos)
