@@ -33,7 +33,7 @@ public:
     virtual void init(int& argc,char** argv,bool connect=TRUE);
 
     // Exit application
-    virtual void exit(FXint code=0);
+    virtual void exit(int code=0);
 
     // Delete application object
     virtual ~XFileView();
