@@ -9,8 +9,8 @@
 \n \
                                   XFE, X File Explorer File Manager\n \
 \n \
-                                    <http://roland65.free.fr/Xfe>\n \
-                                <http://sourceforge.net/projects/Xfe>\n \
+                                    <http://roland65.free.fr/xfe>\n \
+                                <http://sourceforge.net/projects/xfe>\n \
 \n \
 \n \
 \n \
@@ -46,11 +46,12 @@
     - Commander/Explorer interface with four file manager modes : a) one panel, b) a folder tree\n \
       and one panel, c) two panels and d) a folder tree and two panels\n \
     - Panels synchronization and switching\n \
-    - Integrated text editor (X File Write, xfw)\n \
-    - Integrated text viewer (X File View, xfv)\n \
-    - Integrated image viewer (X File Image, xfi)\n \
-    - Integrated package (rpm or deb) viewer / installer / uninstaller (X File Package, xfp)\n \
+    - Integrated text editor (X File Write, Xfw)\n \
+    - Integrated text viewer (X File View, Xfv)\n \
+    - Integrated image viewer (X File Image, Xfi)\n \
+    - Integrated package (rpm or deb) viewer / installer / uninstaller (X File Package, Xfp)\n \
     - Custom shell scripts (like Nautilus scripts)\n \
+    - Search files and directories\n \
     - Copy/Cut/Paste files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Drag and Drop files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Root mode with authentication by su or sudo\n \
@@ -100,7 +101,7 @@
     * Cut to clipboard                   - Ctrl-X\n \
     * Deselect all                       - Ctrl-Z\n \
     * Display help                       - F1\n \
-    * Create new file                    - Ctrl-N\n \
+    * Create new file                    - F2\n \
     * Create new folder                  - F7\n \
     * Big icon list                      - F10\n \
     * Small icon list                    - F11\n \
@@ -122,7 +123,7 @@
     * Switch panels                     - Ctrl-K\n \
     * Clear location bar                - Ctrl-L\n \
     * Mount file system (Linux only)    - Ctrl-M\n \
-    * Rename file                       - F2\n \
+    * Rename file                       - Ctrl-N\n \
     * Refresh panels                    - Ctrl-R\n \
     * Symlink files to location         - Ctrl-S\n \
     * Launch terminal                   - Ctrl-T\n \
@@ -147,7 +148,7 @@
     * Empty trash can                   - Ctrl-Del\n \
 \n \
 \n \
- Below are the default X File Image key bindings. These key bindings are specific to the xfi application.\n \
+ Below are the default X File Image key bindings. These key bindings are specific to the Xfi application.\n \
 \n \
     * Zoom to fit window                - Ctrl-F\n \
     * Mirror image horizontally         - Ctrl-H\n \
@@ -157,7 +158,7 @@
     * Mirror image vertically           - Ctrl-V\n \
 \n \
 \n \
- Below are the default X File Write key bindings. These key bindings are specific to the xfw application.\n \
+ Below are the default X File Write key bindings. These key bindings are specific to the Xfw application.\n \
 \n \
     * Toggle word wrap mode             - Ctrl-K\n \
     * Goto line                         - Ctrl-L\n \
@@ -171,12 +172,12 @@
     * Undo last change                  - Ctrl-Z\n \
 \n \
 \n \
- X File View (xfv) and X File Package (xfp) only use some of the global key bindings.\n \
+ X File View (Xfv) and X File Package (Xfp) only use some of the global key bindings.\n \
 \n \
  Note that all the default key bindings listed above can be customized in the Xfe Preferences dialog. However,\n \
  some key actions are hardcoded an cannot be changed. These include:\n \
 \n \
-    * Ctrl-+ and Ctrl--                 - zoom in and zoom out image in xfi\n \
+    * Ctrl-+ and Ctrl--                 - zoom in and zoom out image in Xfi\n \
     * Shift-F10                         - display context menus in Xfe\n \
     * Return                            - enter folders in file lists, open files, select button actions, etc.\n \
     * Space                             - enter folders in file lists\n \
@@ -212,22 +213,22 @@
  Be careful to quit Xfe before manually editing any configuration file, otherwise changes could not be taken\n \
  into account.\n \
 \n \
- The system-wide configuration file Xferc is located in /usr/share/Xfe, /usr/local/share/Xfe\n \
- or /opt/local/share/Xfe, in the given order of precedence.\n \
+ The system-wide configuration file xferc is located in /usr/share/xfe, /usr/local/share/xfe\n \
+ or /opt/local/share/xfe, in the given order of precedence.\n \
 \n \
  Starting with version 1.32, the location of the local configuration files has changed. This is to be compliant\n \
  with the freedesktop.org standards.\n \
  \n \
- The local configuration files for Xfe, xfw, xfv, xfi, xfp are now located in the ~/.config/Xfe folder.\n \
- They are named Xferc, xfwrc, xfvrc, xfirc and xfprc.\n \
+ The local configuration files for Xfe, Xfw, Xfv, Xfi, Xfp are now located in the ~/.config/xfe folder.\n \
+ They are named xferc, xfwrc, xfvrc, xfirc and xfprc.\n \
  \n \
  At the very first Xfe run, the system-wide configuration file is copied into the local configuration file\n \
- ~/.config/Xfe/Xferc which does not exists yet. If the system-wide configuration file is not found\n \
+ ~/.config/xfe/xferc which does not exists yet. If the system-wide configuration file is not found\n \
  (in case of an unusal install place), a dialog asks the user to select the right place. It is thus easier to\n \
  customize Xfe (this is particularly true for the file associations) by hand editing because all the local options are\n \
  located in the same file.\n \
 \n \
- Default PNG icons are located in /usr/share/Xfe/icons/Xfe-theme or /usr/local/share/Xfe/icons/Xfe-theme, depending\n \
+ Default PNG icons are located in /usr/share/xfe/icons/xfe-theme or /usr/local/share/xfe/icons/xfe-theme, depending\n \
  on your installation. You can easily change the icon theme path in Preferences dialog.\n \
 \n \
 \n \
@@ -239,7 +240,7 @@
  select the files you want to proceed, then right click on the file list and go to the Scripts sub menu. Last, choose\n \
  the script you want to apply on the selected files.\n \
 \n \
- The script files must be located in the ~/.config/Xfe/scripts folder and have to be executable. You can organize\n \
+ The script files must be located in the ~/.config/xfe/scripts folder and have to be executable. You can organize\n \
  this folder as you like by using sub-folders. You can use the Tools / Go to script folder menu item to directly go\n \
  to the script folder and manage it.\n \
 \n \
@@ -266,6 +267,22 @@
  Most often, it is possible to directly use Nautilus scripts found on the Internet without modifications.\n \
 \n \
 \n \
+\n \
+ Search files and directories\n \
+ =-=-=-=-=-=-=-=-=-=-=-=-=-=-=\n \
+\n \
+\n \
+ Xfe can quickly search files and directories by using find and grep command backends. This is done through the\n \
+ Tools / Search files menu item (or by using the Ctrl-F shortcut).\n \
+\n \
+ In the search window, users can then specify usual search patterns like name and text, but more sophisticated search\n \
+ options are also available (size, date, permissions, users, groups, follow symlinks and empty files). Results appear\n \
+ in a file list and users can use the right click menu to manage their files, the same way as they do in the file\n \
+ panels.\n \
+\n \
+ The search can be interrupted by clicking on the Stop button or pressing the Escape key.\n \
+\n \
+\n \
 \n \
   Non Latin based languages\n \
   =-=-=-=-=-=-=-=-=-=-=-=-=\n \
@@ -319,7 +336,7 @@
   Translations\n \
   =-=-=-=-=-=-=\n \
  \n \
- Xfe is now available in 19 languages but some translations are only partial. To translate Xfe to your language,\n \
+ Xfe is now available in 23 languages but some translations are only partial. To translate Xfe to your language,\n \
  open the Xfe.pot file located in the po folder of the source tree with a software like poedit, kbabel\n \
  or gtranslator and fill it with your translated strings (be careful to the hotkeys and c-format characters),\n \
  and then send it back to me. I'll be pleased to integrate your work in the next Xfe release.\n \
@@ -335,7 +352,7 @@
  Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
  patches, translations, tests and advices.\n \
 \n \
- [Last revision: 21/08/2013]\n \
+ [Last revision: 16/09/2013]\n \
 \n \
  ")
 ;
