@@ -21,7 +21,7 @@ FXIcon *copy_clpicon, *cut_clpicon, *delete_big_permicon, *delete_bigicon, *dese
 FXIcon *dirupicon, *editicon, *entericon, *errorbigicon, *exptreeicon;
 FXIcon *filedelete_permicon, *filedeleteicon, *fileopenicon;
 FXIcon *viewicon, *filtericon, *find_againicon, *fliplricon, *flipudicon, *floppyicon;
-FXIcon *fontsicon, *gotobigicon, *gotolineicon, *harddiskicon, *helpicon, *hidehiddenicon;
+FXIcon *fontsicon, *gotobigicon, *gotodiricon, *gotolineicon, *harddiskicon, *helpicon, *hidehiddenicon;
 FXIcon *hidenumbersicon, *hidethumbicon, *homeicon, *infobigicon, *invselicon, *link_bigicon;
 FXIcon *locationicon, *lowercaseicon, *maphosticon, *miniappicon, *miniblockdevicon, *minibrokenlinkicon;
 FXIcon *minichardevicon, *minidocicon, *miniexecicon, *minifolderclosedicon;
@@ -139,6 +139,7 @@ FXbool loadAppIcons(FXApp *app)
 	success=( (floppyicon=loadiconfile(app,iconpath,"floppy.png")) != NULL ) & success;
 	success=( (fontsicon=loadiconfile(app,iconpath,"fonts.png")) != NULL ) & success;
 	success=( (gotobigicon=loadiconfile(app,iconpath,"gotobig.png")) != NULL ) & success;
+	success=( (gotodiricon=loadiconfile(app,iconpath,"gotodir.png")) != NULL ) & success;
 	success=( (gotolineicon=loadiconfile(app,iconpath,"gotoline.png")) != NULL ) & success;
 	success=( (harddiskicon=loadiconfile(app,iconpath,"harddisk.png")) != NULL ) & success;
 	success=( (helpicon=loadiconfile(app,iconpath,"help.png")) != NULL ) & success;
