@@ -24,6 +24,7 @@
 
 // Add FOX hacks
 #include "foxhacks.cpp"
+#include "clearlooks.cpp"
 
 // Main window
 FXMainWindow *mainWindow;
@@ -213,7 +214,7 @@ int panel_mode=-1;
 #define hand_height 32
 #define hand_x_hot 6
 #define hand_y_hot 1
- static const unsigned char hand_bits[] = {
+ static const FXuchar hand_bits[] = {
 	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00,
 	0x90, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90, 0x07, 0x00, 0x00,
 	0x97, 0x1a, 0x00, 0x00, 0x99, 0x2a, 0x00, 0x00, 0x11, 0x28, 0x00, 0x00,
@@ -226,7 +227,7 @@ int panel_mode=-1;
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
  
- static const unsigned char hand_mask_bits[] = {
+ static const FXuchar hand_mask_bits[] = {
 	0x00, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00,
 	0xf0, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0xf0, 0x07, 0x00, 0x00,
 	0xf7, 0x1f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x3f, 0x00, 0x00,
