@@ -42,9 +42,9 @@
 #define MIN_PANEL_WIDTH 100
 #endif
 
-// Maximum length of a file name
+// Maximum length of a file path
 #ifndef MAXPATHLEN
-#define MAXPATHLEN 1024
+#define MAXPATHLEN 4096
 #endif
 
 // Maximum length of a command line
@@ -73,8 +73,8 @@
 #endif
 
 // Maximum number of path links 
-#ifndef MAXLINKS
-#define MAX_LINKS 40
+#ifndef MAX_LINKS
+#define MAX_LINKS 1000
 #endif
 
 // Run history size
@@ -115,6 +115,11 @@
 #define XFECONFIGPATH "xfe"
 #endif
 
+// Scripts path
+#ifndef SCRIPTPATH
+#define SCRIPTPATH "scripts"
+#endif
+
 // Local trashcan directory path
 #ifndef TRASHPATH
 #define TRASHPATH "Trash"
