@@ -27,7 +27,7 @@
 // Parse accelerator from string
 FXHotKey _parseAccel(const FXString& string)
 {
-	register unsigned int code=0,mods=0;
+	register FXuint code=0,mods=0;
 	register int pos=0;
 
 	// Parse leading space
@@ -431,9 +431,9 @@ int createTrashinfo(FXString pathname, FXString trashpathname, FXString trashfil
 
 // Return mime type of a file
 // Makes use of the Unix file command, thus this function may be slow
-FXString mimetype(FXString filepath)
+FXString mimetype(FXString pathname)
 {
-    FXString cmd ="/usr/bin/file -b -i " + filepath;
+    FXString cmd ="/usr/bin/file -b -i " + pathname;
     FILE *filecmd=popen(cmd.text(),"r");
     if(!filecmd)
     {
@@ -471,42 +471,42 @@ FXString quote(FXString str)
 // Test if a string is encoded in UTF-8
 // "length" is the number of bytes of the string to consider
 // Taken from the weechat project. Original author FlashCode <flashcode@flashtux.org>
-FXbool isUtf8(const char* string, unsigned int length)
+FXbool isUtf8(const char* string, FXuint length)
 {
-    unsigned int n=0;
+    FXuint n=0;
 	while (n<length)
     {
         // UTF-8, 2 bytes, should be: 110vvvvv 10vvvvvv
-        if (((unsigned char)(string[0]) & 0xE0) == 0xC0)
+        if (((FXuchar)(string[0]) & 0xE0) == 0xC0)
         {
-            if (!string[1] || (((unsigned char)(string[1]) & 0xC0) != 0x80))
+            if (!string[1] || (((FXuchar)(string[1]) & 0xC0) != 0x80))
                 return FALSE;
             string += 2;
 			n += 2;
         }
         // UTF-8, 3 bytes, should be: 1110vvvv 10vvvvvv 10vvvvvv
-        else if (((unsigned char)(string[0]) & 0xF0) == 0xE0)
+        else if (((FXuchar)(string[0]) & 0xF0) == 0xE0)
         {
             if (!string[1] || !string[2]
-                || (((unsigned char)(string[1]) & 0xC0) != 0x80)
-                || (((unsigned char)(string[2]) & 0xC0) != 0x80))
+                || (((FXuchar)(string[1]) & 0xC0) != 0x80)
+                || (((FXuchar)(string[2]) & 0xC0) != 0x80))
                 return FALSE;
             string += 3;
 			n += 3;
        }
         // UTF-8, 4 bytes, should be: 11110vvv 10vvvvvv 10vvvvvv 10vvvvvv
-        else if (((unsigned char)(string[0]) & 0xF8) == 0xF0)
+        else if (((FXuchar)(string[0]) & 0xF8) == 0xF0)
         {
             if (!string[1] || !string[2] || !string[3]
-                || (((unsigned char)(string[1]) & 0xC0) != 0x80)
-                || (((unsigned char)(string[2]) & 0xC0) != 0x80)
-                || (((unsigned char)(string[3]) & 0xC0) != 0x80))
+                || (((FXuchar)(string[1]) & 0xC0) != 0x80)
+                || (((FXuchar)(string[2]) & 0xC0) != 0x80)
+                || (((FXuchar)(string[3]) & 0xC0) != 0x80))
                 return FALSE;
             string += 4;
 			n += 4;
         }
         // UTF-8, 1 byte, should be: 0vvvvvvv
-        else if ((unsigned char)(string[0]) >= 0x80)
+        else if ((FXuchar)(string[0]) >= 0x80)
 		{
             return FALSE;
 		}
@@ -622,7 +622,7 @@ FXulong dirsize(const char* path)
 // Caution: this only works if nbfiles and nbsubdirs are initialized to 0 in the calling function
 // After that, nbfiles contains the total number of files (including the count of sub directories)
 // and nbsubdirs the number of sub directories
-FXulong pathsize(char* path, unsigned int* nbfiles, unsigned int* nbsubdirs)
+FXulong pathsize(char* path, FXuint* nbfiles, FXuint* nbsubdirs)
 {
 	struct stat statbuf;
 	struct dirent *dirp;
@@ -680,7 +680,7 @@ FXString hSize(char* size)
 	char buf[128];
 	FXString hsize;
 
-    unsigned long long lsize = strtoull(size,NULL,10);
+    FXulong lsize = strtoull(size,NULL,10);
     float fsize=0.0;
 
 	strlcpy(suf,_("bytes"),sizeof(suf)); 
@@ -711,7 +711,12 @@ FXString hSize(char* size)
             snprintf(buf,sizeof(buf),"%.1f %s",fsize,suf);
     }
     else
+
+#if __WORDSIZE == 64
+        snprintf(buf,sizeof(buf),"%lu %s",lsize,suf);
+#else
         snprintf(buf,sizeof(buf),"%llu %s",lsize,suf);
+#endif
 	
 	hsize=buf;
 	return hsize;
@@ -814,7 +819,7 @@ FXString fileToURI(const FXString& file)
 
 // Convert the deletion date to the number of seconds since the epoch
 // The string representing the deletion date must be in the format YYYY-MM-DDThh:mm:ss
-long deltime(FXString delstr)
+FXlong deltime(FXString delstr)
 {	
 	// Decompose the date into year, month, day, hour, minutes and seconds
 	FXString year=delstr.mid(0,4);
@@ -833,7 +838,7 @@ long deltime(FXString delstr)
 	tmval.tm_mon=atoi(mon.text())-1;
 	tmval.tm_year=atoi(year.text())-1900;
 	tmval.tm_isdst=0;
-	long t=(long)mktime(&tmval);
+	FXlong t=(FXlong)mktime(&tmval);
 	
 	// If conversion failed, return 0
 	if (t<0)
@@ -1062,7 +1067,7 @@ FXbool info(const FXString& file,struct stat& inf)
 
 // Return permissions string
 // (the FOX function FXSystem::modeString() seems to use another format for the mode field) 
-FXString permissions(unsigned int mode)
+FXString permissions(FXuint mode)
 {
 	char result[11];
 	result[0]=S_ISLNK(mode) ? 'l' : S_ISREG(mode) ? '-' : S_ISDIR(mode) ? 'd' : S_ISCHR(mode) ? 'c' : S_ISBLK(mode) ? 'b' : S_ISFIFO(mode) ? 'p' : S_ISSOCK(mode) ? 's' : '?';
@@ -1108,7 +1113,7 @@ FXbool identical(const FXString& file1,const FXString& file2)
 // Start or stop wait cursor (start if type is BEGIN_CURSOR, stop if type is END_CURSOR)
 // Do nothing if type is QUERY_CURSOR or anything different from BEGIN_CURSOR and END_CURSOR)
 // Return wait cursor count (0 means wait cursor is not set)
-int setWaitCursor(FXApp* app, unsigned int type)
+int setWaitCursor(FXApp* app, FXuint type)
 {
 	static int waitcount=0;
 	
