@@ -143,7 +143,7 @@ FXString createTrashpathname(FXString, FXString);
 int createTrashinfo(FXString, FXString, FXString, FXString);
 FXString mimetype(FXString);
 FXString quote(FXString);
-FXbool isUtf8(const char*, unsigned int);
+FXbool isUtf8(const char*, FXuint);
 int statrep(const char*, struct stat*);
 int lstatrep(const char*, struct stat*);
 #if defined(linux)
@@ -152,14 +152,14 @@ int lstatmt(const char*, struct stat*);
 size_t strlcpy(char*, const char*, size_t);
 size_t strlcat(char*, const char*, size_t);
 FXulong dirsize(const char*);
-FXulong pathsize(char*, unsigned int*, unsigned int*);
+FXulong pathsize(char*, FXuint*, FXuint*);
 FXString hSize(char*);
 FXString cleanPath(const FXString);
 FXString filePath(const FXString);
 FXString filePath(const FXString, const FXString);
 FXString fileFromURI(FXString);
 FXString fileToURI(const FXString&);
-long deltime(FXString);
+FXlong deltime(FXString);
 int isEmptyDir(const FXString);
 int hasSubDirs(const FXString);
 FXbool exists(const FXString&);
@@ -171,10 +171,10 @@ FXbool isReadable(const FXString&);
 FXbool isReadExecutable(const FXString&);
 FXbool isLink(const FXString&);
 FXbool info(const FXString&, struct stat&);
-FXString permissions(unsigned int);
+FXString permissions(FXuint);
 FXString readLink(const FXString&);
 FXbool identical(const FXString& ,const FXString&);
-int setWaitCursor(FXApp*, unsigned int);
+int setWaitCursor(FXApp*, FXuint);
 int runinxvt(FXString);
 
 #endif
