@@ -1677,7 +1677,7 @@ static void refresh(int row1, int row2, int col1, int col2)
  */
 static void show_selection(int row1, int row2, int col1, int col2)
 {
-    int r1, c1, r2, c2, sr, sc, er, ec;
+    int r1=0, c1=0, r2=0, c2=0, sr, sc, er, ec;
     int x1, x2, y, row;
 
     if (selend1.se_type == NOSEL || selend2.se_type == NOSEL)
