@@ -37,7 +37,6 @@
 #include <unistd.h>
 #include <signal.h>
 #include <fcntl.h>
-#include <utmp.h>
 #include <sys/param.h>
 #if __FreeBSD_version >= 900007
 #    include <utmpx.h>
@@ -203,7 +202,8 @@ static void catch_sig(int sig)
 {
     tidy_utmp();
     signal(sig,SIG_DFL);
-    setuid(getuid());
+	if (setuid(getuid())<0)
+		error("setuid() failed\n");;       	
     kill(getpid(),sig);
 }
 
@@ -394,7 +394,6 @@ static int get_tslot(char* ttynam)
 static char* get_pseudo_tty(int* pmaster, int* pslave)
 {
     int mfd = 0, sfd = 0;
-    char *ttynam = NULL;
 #if defined(BSD_PTY) || defined(__FreeBSD__)
     char *s3, *s4;
     static char ptyc3[] = "pqrstuvwxyz";
@@ -435,7 +434,9 @@ static char* get_pseudo_tty(int* pmaster, int* pslave)
         error("could not open slave tty %s",ttynam);
         return(NULL);
     }
-#endif /* BSD_PTY */
+#else /* BSD_PTY */
+    char *ttynam = NULL;
+#endif
 
 #ifdef SVR4_PTY
 
@@ -658,8 +659,10 @@ int run_command(char* command, char** argv)
         setpgrp (0, pgid);
 #endif /* BSD_TTY */
         set_ttymodes();
-        setgid(getgid());
-        setuid(uid);
+        if (setgid(getgid())<0)
+        	error("setgid() failed\n");;
+        if (setuid(uid)<0)
+         	error("setuid() failed\n");;       	
         execvp(command,argv);
         error("Couldn't execute %s",command);
         quit(1);
